@@ -1,6 +1,3 @@
-# commandinterface.py
-# this module supplies the command line interface for plotting
-
 #    Copyright (C) 2004 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -20,15 +17,12 @@
 ##############################################################################
 
 """
-Module supplies the command interface used in the program, and for
-external programs.
+Definitions for command line interface
 """
 
-from __future__ import division, print_function
 import os.path
 import numpy as N
 
-from ..compat import cbasestr
 from .. import qtall as qt
 from .. import setting
 from .. import embed
@@ -59,7 +53,9 @@ class CommandInterface(qt.QObject):
         'Add',
         'AddCustom',
         'AddImportPath',
+        'CurrentPath',
         'CloneWidget',
+        'SetCompatLevel',
         'CreateHistogram',
         'DatasetPlugin',
         'FilterDatasets',
@@ -95,7 +91,7 @@ class CommandInterface(qt.QObject):
         'TagDatasets',
         'To',
         'WidgetType',
-        ]
+    ]
 
     # commands for importing data
     import_commands = []
@@ -107,7 +103,7 @@ class CommandInterface(qt.QObject):
         'Export',
         'Print',
         'Save',
-        ]
+    ]
 
     def __init__(self, document):
         """Initialise the interface."""
@@ -171,9 +167,9 @@ class CommandInterface(qt.QObject):
 
     def AddCustom(self, ctype, name, val, mode='appendalways'):
         """Add a custom definition for evaluation of expressions.
-	This can define a constant (can be in terms of other
-	constants), a function of 1 or more variables, or a function
-	imported from an external python module.
+        This can define a constant (can be in terms of other
+        constants), a function of 1 or more variables, or a function
+        imported from an external python module.
 
         ctype is "constant", "function", "definition" (either
         constant or function), "import", "color" or "colormap".
@@ -200,7 +196,7 @@ class CommandInterface(qt.QObject):
         if ctype == 'colormap':
             self.document.evaluate.validateProcessColormap(val)
         else:
-            if not isinstance(val, cbasestr):
+            if not isinstance(val, str):
                 raise RuntimeError('Value should be string')
 
         if mode not in ('appendalways', 'append', 'replace'):
@@ -223,7 +219,7 @@ class CommandInterface(qt.QObject):
                     if mode == 'append':
                         del vals[i]
                         vals.append(item)
-                    else: # replace
+                    else:  # replace
                         vals[i] = item
                     break
             else:
@@ -235,7 +231,7 @@ class CommandInterface(qt.QObject):
 
     def AddImportPath(self, directory):
         """Add directory to import file path."""
-        assert isinstance(directory, cbasestr)
+        assert isinstance(directory, str)
         self.importpath.append(directory)
 
     def CloneWidget(self, widget, newparent, newname=None):
@@ -275,8 +271,14 @@ class CommandInterface(qt.QObject):
         self.document.applyOperation(op)
 
         if self.verbose:
-            print(_('Constructed histogram of "%s", creating datasets'
-                    ' "%s" and "%s"') % (inexpr, outbinsds, outvalsds))
+            print(_(
+                'Constructed histogram of "%s", creating datasets'
+                ' "%s" and "%s"') % (inexpr, outbinsds, outvalsds)
+            )
+
+    def CurrentPath(self):
+        """Return the current path (set by To())."""
+        return self.currentwidget.path
 
     def DatasetPlugin(self, pluginname, fields, datasetnames={}):
         """Use a dataset plugin.
@@ -296,13 +298,15 @@ class CommandInterface(qt.QObject):
             raise RuntimeError("Cannot find dataset plugin '%s'" % pluginname)
 
         # do the work
-        op = operations.OperationDatasetPlugin(plugin, fields,
-                                               datasetnames=datasetnames)
+        op = operations.OperationDatasetPlugin(
+            plugin, fields, datasetnames=datasetnames)
         outdatasets = self.document.applyOperation(op)
 
         if self.verbose:
-            print(_("Used dataset plugin %s to make datasets %s") % (
-                pluginname, ', '.join(outdatasets)))
+            print(_(
+                "Used dataset plugin %s to make datasets %s") % (
+                    pluginname, ', '.join(outdatasets))
+            )
 
     def Remove(self, name):
         """Remove a widget from the dataset."""
@@ -424,6 +428,16 @@ class CommandInterface(qt.QObject):
         if self.verbose:
             print( _( "Set setting '%s' to %s") % (setting_path, repr(setn.get())) )
 
+    def SetCompatLevel(self, level):
+        """Set the compatibility level.
+
+        As a side effect, this wipes any widgets in the document
+        and resets all settings.
+
+        If level<0, then choose the latest version
+        """
+        self.document.setCompatLevel(level)
+
     def SetData(self, name, val, symerr=None, negerr=None, poserr=None):
         """Create/set dataset name with values (and optionally errors)."""
 
@@ -433,13 +447,16 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Set dataset '%s':\n"
-                  " Values = %s\n"
-                  " Symmetric errors = %s\n"
-                  " Negative errors = %s\n"
-                  " Positive errors = %s") % (
-                      name, str(data.data), str(data.serr),
-                      str(data.nerr), str(data.perr))
+                _(
+                    "Set dataset '%s':\n"
+                    " Values = %s\n"
+                    " Symmetric errors = %s\n"
+                    " Negative errors = %s\n"
+                    " Positive errors = %s"
+                ) % (
+                    name, str(data.data), str(data.serr),
+                    str(data.nerr), str(data.perr)
+                )
             )
 
     def SetDataDateTime(self, name, vals):
@@ -484,13 +501,15 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Set dataset '%s' based on expression:\n"
-                  " Values = %s\n"
-                  " Symmetric errors = %s\n"
-                  " Negative errors = %s\n"
-                  " Positive errors = %s") % (
-                      name, str(data.data), str(data.serr),
-                      str(data.nerr), str(data.perr))
+                _(
+                    "Set dataset '%s' based on expression:\n"
+                    " Values = %s\n"
+                    " Symmetric errors = %s\n"
+                    " Negative errors = %s\n"
+                    " Positive errors = %s"
+                ) % (
+                    name, str(data.data), str(data.serr),
+                    str(data.nerr), str(data.perr))
             )
             if parametric:
                 print(_(" Where t goes form %g:%g in %i steps") % parametric)
@@ -521,21 +540,23 @@ class CommandInterface(qt.QObject):
         """
 
         parts = {'data': val, 'serr': symerr, 'nerr': negerr, 'perr': poserr}
-        op = operations.OperationDatasetCreateRange(name, numsteps, parts,
-                                                    linked)
+        op = operations.OperationDatasetCreateRange(
+            name, numsteps, parts, linked)
         self.document.applyOperation(op)
 
         if self.verbose:
             print(
-                _("Set dataset '%s' based on range:\n"
-                  " Number of steps = %i\n"
-                  " Range of data = %s\n"
-                  " Range of symmetric error = %s\n"
-                  " Range of positive error = %s\n"
-                  " Range of negative error = %s") % (
-                      name, numsteps, repr(val),
-                      repr(symerr), repr(poserr), repr(negerr))
-              )
+                _(
+                    "Set dataset '%s' based on range:\n"
+                    " Number of steps = %i\n"
+                    " Range of data = %s\n"
+                    " Range of symmetric error = %s\n"
+                    " Range of positive error = %s\n"
+                    " Range of negative error = %s"
+                ) % (
+                    name, numsteps, repr(val),
+                    repr(symerr), repr(poserr), repr(negerr))
+            )
 
     def SetData2DExpression(self, name, expr, linked=False):
         """Create a 2D dataset based on expressions
@@ -550,12 +571,14 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Set 2D dataset '%s' based on expressions\n"
-                  " expression = %s\n"
-                  " linked to expression = %s\n"
-                  " Made a dataset (%i x %i)") % (
-                      name, repr(expr), repr(linked),
-                      data.data.shape[0], data.data.shape[1])
+                _(
+                    "Set 2D dataset '%s' based on expressions\n"
+                    " expression = %s\n"
+                    " linked to expression = %s\n"
+                    " Made a dataset (%i x %i)"
+                ) % (
+                    name, repr(expr), repr(linked),
+                    data.data.shape[0], data.data.shape[1])
             )
 
     def SetData2DExpressionXYZ(self, name, xexpr, yexpr, zexpr, linked=False):
@@ -573,16 +596,18 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Made 2D dataset '%s' based on expressions:\n"
-                  " X expression = %s\n"
-                  " Y expression = %s\n"
-                  " Z expression = %s\n"
-                  " is linked to expression = %s\n"
-                  " Shape (%i x %i)") % (
-                      name,
-                      repr(xexpr), repr(yexpr), repr(zexpr),
-                      repr(linked),
-                      data.data.shape[0], data.data.shape[1])
+                _(
+                    "Made 2D dataset '%s' based on expressions:\n"
+                    " X expression = %s\n"
+                    " Y expression = %s\n"
+                    " Z expression = %s\n"
+                    " is linked to expression = %s\n"
+                    " Shape (%i x %i)"
+                ) % (
+                    name,
+                    repr(xexpr), repr(yexpr), repr(zexpr),
+                    repr(linked),
+                    data.data.shape[0], data.data.shape[1])
             )
 
     def SetData2DXYFunc(self, name, xstep, ystep, expr, linked=False):
@@ -600,15 +625,17 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Set 2D dataset '%s' based on function of x and y\n"
-                  " X steps = %s\n"
-                  " Y steps = %s\n"
-                  " Expression = %s\n"
-                  " linked to expression = %s\n"
-                  " Made a dataset (%i x %i)") % (
-                      name, repr(xstep), repr(ystep),
-                      repr(expr), repr(linked),
-                      data.data.shape[0], data.data.shape[1])
+                _(
+                    "Set 2D dataset '%s' based on function of x and y\n"
+                    " X steps = %s\n"
+                    " Y steps = %s\n"
+                    " Expression = %s\n"
+                    " linked to expression = %s\n"
+                    " Made a dataset (%i x %i)"
+                ) % (
+                    name, repr(xstep), repr(ystep),
+                    repr(expr), repr(linked),
+                    data.data.shape[0], data.data.shape[1])
             )
 
     def SetData2D(self, name, data, xrange=None, yrange=None,
@@ -642,9 +669,10 @@ class CommandInterface(qt.QObject):
              (ycent is not None and len(ycent) != data.shape[0]) ):
             raise ValueError("xcent and ycent lengths must be data shape")
 
-        data = datasets.Dataset2D(data, xrange=xrange, yrange=yrange,
-                                  xedge=xedge, yedge=yedge,
-                                  xcent=xcent, ycent=ycent)
+        data = datasets.Dataset2D(
+            data, xrange=xrange, yrange=yrange,
+            xedge=xedge, yedge=yedge,
+            xcent=xcent, ycent=ycent)
         op = operations.OperationDatasetSet(name, data)
         self.document.applyOperation(op)
 
@@ -660,9 +688,8 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _("Set text dataset '%s'\n"
-                  "Values = %s") % (
-                      name, repr(data.data))
+                _("Set text dataset '%s'\nValues = %s") % (
+                    name, repr(data.data))
             )
 
     def GetData(self, name):
@@ -880,7 +907,9 @@ class CommandInterface(qt.QObject):
 
         if self.verbose:
             print(
-                _('Filtered datasets %s using expression %s. '
-                  'Output prefix=%s, suffix=%s') % (
-                      dataset_list, filterexpr, prefix, suffix)
+                _(
+                    'Filtered datasets %s using expression %s. '
+                    'Output prefix=%s, suffix=%s'
+                ) % (
+                    dataset_list, filterexpr, prefix, suffix)
             )
