@@ -19,9 +19,7 @@
 """Helper for doing the plotting of the document.
 """
 
-from __future__ import division
 from .. import qtall as qt
-from .. import setting
 from .. import utils
 
 try:
@@ -31,7 +29,7 @@ except ImportError:
     def RecordPaintDevice(width, height, dpix, dpiy):
         return qt.QPicture()
 
-class DrawState(object):
+class DrawState:
     """Each widget plotted has a recorded state in this object."""
 
     def __init__(self, widget, bounds, clip, helper):
@@ -41,8 +39,8 @@ class DrawState(object):
 
         self.widget = widget
         self.record = RecordPaintDevice(
-            helper.pagesize[0], helper.pagesize[1],
-            helper.dpi[0], helper.dpi[1])
+            int(helper.pagesize[0]), int(helper.pagesize[1]),
+            int(helper.dpi[0]), int(helper.dpi[1]))
         self.bounds = bounds
         self.clip = clip
 
@@ -102,7 +100,7 @@ class RecordPainter(PainterRoot):
     def __exit__(self, exc_type, exc_value, traceback):
         self.helper.widgetstack.pop()
 
-class PaintHelper(object):
+class PaintHelper:
     """Helper used when painting widgets.
 
     Designed to be used for a particular page.
@@ -170,8 +168,10 @@ class PaintHelper(object):
 
     def sizeAtDpi(self, dpi):
         """Return a tuple size for the page given an output device dpi."""
-        return ( int(self.pagesize[0]/self.dpi[0] * dpi),
-                 int(self.pagesize[1]/self.dpi[1] * dpi) )
+        return (
+            int(self.pagesize[0]/self.dpi[0] * dpi),
+            int(self.pagesize[1]/self.dpi[1] * dpi)
+        )
 
     def painter(self, widget, bounds, clip=None, layer=None):
         """Return a painter for use when drawing the widget.
@@ -269,7 +269,7 @@ class PaintHelper(object):
         origimg = origpix.toImage()
         # store most recent widget here
         lastwidget = [None]
-        
+
         def rendernextstate(state):
             """Recursively draw painter.
 
@@ -283,7 +283,7 @@ class PaintHelper(object):
             painter.setRenderHint(qt.QPainter.TextAntialiasing, antialias)
             # this makes the small image draw from x-box->x+box, y-box->y+box
             # translate would get overriden by coordinate system playback
-            painter.setWindow(x-box,y-box,box*2+1,box*2+1)
+            painter.setWindow(int(x-box), int(y-box), int(box*2+1), int(box*2+1))
             state.record.play(painter)
             painter.end()
             newimg = pixmap.toImage()
