@@ -19,11 +19,9 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 import math
 import numpy as N
 
-from ..compat import crange
 from .. import utils
 
 """Algorithms for working with axis ticks.
@@ -36,7 +34,7 @@ by looking though a list of allowable interval values (after taking
 account of what power of 10 the coordinates are in).
 """
 
-class AxisTicksBase(object):
+class AxisTicksBase:
     """Base class of axis ticks classes."""
 
     def __init__( self, minval, maxval, numticks, numminorticks,
@@ -54,8 +52,11 @@ class AxisTicksBase(object):
          is tuple as returned in self.interval after calling getTicks()
         """
 
-        self.minval = minval
-        self.maxval = maxval
+        # clip to sensible range
+        self.minval = max(min(minval, 1e100), -1e100)
+        self.maxval = max(min(maxval, 1e100), -1e100)
+
+        # tick parameters
         self.numticks = numticks
         self.numminorticks = numminorticks
         self.logaxis = logaxis
@@ -77,12 +78,14 @@ class AxisTicks(AxisTicksBase):
     # the allowed values we allow ticks to increase by
     # first values are the major tick intervals, followed by a list
     # of allowed minors
-    allowed_minorintervals_linear = { 1.:  (0.1, 0.2, 0.5),
-                                      2.:  (0.2, 0.5, 1.),
-                                      5.:  (0.5, 1., 2.5),
-                                      2.5: (0.5,) }
+    allowed_minorintervals_linear = { 
+        1.:  (0.1, 0.2, 0.5),
+        2.:  (0.2, 0.5, 1.),
+        5.:  (0.5, 1., 2.5),
+        2.5: (0.5,)
+    }
     # just get the allowable majors
-    allowed_intervals_linear = sorted(allowed_minorintervals_linear.keys())
+    allowed_intervals_linear = sorted(allowed_minorintervals_linear)
 
     # the allowed values we can increase by in log space
     # by default we increase by 10^3
@@ -189,10 +192,10 @@ class AxisTicks(AxisTicksBase):
 
         ticks = []
         # iterate over range in log space
-        for i in crange(alpha, beta+1):
+        for i in range(alpha, beta+1):
             power = 10.**i
             # add ticks for values in correct range
-            for j in crange(2, 10):
+            for j in range(2, 10):
                 v = power*j
                 # blah log conversions mean we have to use 'fuzzy logic'
                 if ( math.fabs(v - minval)/v < 1e-6 or v > minval ) and \
@@ -309,6 +312,10 @@ class AxisTicks(AxisTicksBase):
         if abs(self.minval - self.maxval) < 1e-99:
             self.maxval = self.minval + 1.
 
+            # for large numbers this may be the case
+            if self.maxval == self.minval:
+                self.minval, self.maxval = 0., 1.
+
         minval, maxval, tickvals, interval, loginterval = self._tickSelector(
             intervals )
 
@@ -320,7 +327,7 @@ class AxisTicks(AxisTicksBase):
             minorticks = self._calcLinearMinorTickValues(
                 minval, maxval, interval, loginterval,
                 AxisTicks.allowed_minorintervals_linear[interval]
-                )
+            )
 
         else:
             # log axis
@@ -379,53 +386,57 @@ class DateTicks(AxisTicksBase):
     # possible intervals for a time/date axis
     # tuples of ((y, m, d, h, m, s, msec), autoformat)
     intervals = (
-                 ((200, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((100, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((50, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((20, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((10, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((5, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((2, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((1, 0, 0, 0, 0, 0, 0), '%VDY'),
-                 ((0, 6, 0, 0, 0, 0, 0), '%VDY-%VDm'),
-                 ((0, 4, 0, 0, 0, 0, 0), '%VDY-%VDm'),
-                 ((0, 3, 0, 0, 0, 0, 0), '%VDY-%VDm'),
-                 ((0, 2, 0, 0, 0, 0, 0), '%VDY-%VDm'),
-                 ((0, 1, 0, 0, 0, 0, 0), '%VDY-%VDm'),
-                 ((0, 0, 28, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
-                 ((0, 0, 14, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
-                 ((0, 0, 7, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
-                 ((0, 0, 2, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
-                 ((0, 0, 1, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
-                 ((0, 0, 0, 12, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
-                 ((0, 0, 0, 6, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
-                 ((0, 0, 0, 4, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
-                 ((0, 0, 0, 3, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
-                 ((0, 0, 0, 2, 0, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 1, 0, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 30, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 15, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 10, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 5, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 2, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 1, 0, 0), '%VDH:%VDM'),
-                 ((0, 0, 0, 0, 0, 30, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 15, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 10, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 5, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 2, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 1, 0), '%VDH:%VDM:%VDS'),
-                 ((0, 0, 0, 0, 0, 0, 500000), '%VDH:%VDM:%VDVS'),
-                 ((0, 0, 0, 0, 0, 0, 200000), '%VDVS'),
-                 ((0, 0, 0, 0, 0, 0, 100000), '%VDVS'),
-                 ((0, 0, 0, 0, 0, 0, 50000), '%VDVS'),
-                 ((0, 0, 0, 0, 0, 0, 10000), '%VDVS'),
-                 )
+        ((200, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((100, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((50, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((20, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((10, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((5, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((2, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((1, 0, 0, 0, 0, 0, 0), '%VDY'),
+        ((0, 6, 0, 0, 0, 0, 0), '%VDY-%VDm'),
+        ((0, 4, 0, 0, 0, 0, 0), '%VDY-%VDm'),
+        ((0, 3, 0, 0, 0, 0, 0), '%VDY-%VDm'),
+        ((0, 2, 0, 0, 0, 0, 0), '%VDY-%VDm'),
+        ((0, 1, 0, 0, 0, 0, 0), '%VDY-%VDm'),
+        ((0, 0, 28, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
+        ((0, 0, 14, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
+        ((0, 0, 7, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
+        ((0, 0, 2, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
+        ((0, 0, 1, 0, 0, 0, 0), '%VDY-%VDm-%VDd'),
+        ((0, 0, 0, 12, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
+        ((0, 0, 0, 6, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
+        ((0, 0, 0, 4, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
+        ((0, 0, 0, 3, 0, 0, 0), '%VDY-%VDm-%VDd\\\\%VDH:%VDM'),
+        ((0, 0, 0, 2, 0, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 1, 0, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 30, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 15, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 10, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 5, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 2, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 1, 0, 0), '%VDH:%VDM'),
+        ((0, 0, 0, 0, 0, 30, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 15, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 10, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 5, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 2, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 1, 0), '%VDH:%VDM:%VDS'),
+        ((0, 0, 0, 0, 0, 0, 500000), '%VDH:%VDM:%VDVS'),
+        ((0, 0, 0, 0, 0, 0, 200000), '%VDVS'),
+        ((0, 0, 0, 0, 0, 0, 100000), '%VDVS'),
+        ((0, 0, 0, 0, 0, 0, 50000), '%VDVS'),
+        ((0, 0, 0, 0, 0, 0, 10000), '%VDVS'),
+    )
 
-    intervals_sec = N.array([(ms*1e-6+s+mi*60+hr*60*60+dy*24*60*60+
-                              mn*(365/12.)*24*60*60+
-                              yr*365*24*60*60)
-                             for (yr, mn, dy, hr, mi, s, ms), fmt in intervals])
+    intervals_sec = N.array([
+        (
+            ms*1e-6+s+mi*60+hr*60*60+dy*24*60*60 +
+            mn*(365/12.)*24*60*60 +
+            yr*365*24*60*60
+        )
+        for (yr, mn, dy, hr, mi, s, ms), fmt in intervals]
+    )
 
     def bestTickFinder(self, minval, maxval, numticks, extendmin, extendmax,
                        intervals, intervals_sec):
@@ -450,7 +461,7 @@ class DateTicks(AxisTicksBase):
             best = tick1
         else:
             best = tick2
-        besttt, format = intervals[best]
+        besttt, fmt = intervals[best]
 
         mindate = utils.floatToDateTime(minval)
         maxdate = utils.floatToDateTime(maxval)
@@ -469,8 +480,8 @@ class DateTicks(AxisTicksBase):
         # extend bounds if requested
         deltamin = utils.datetimeToFloat(mindate)-utils.datetimeToFloat(mintick)
         if extendmin and (deltamin != 0. and deltamin < delta*0.15):
-            mindate = utils.addTimeTupleToDateTime(minround,
-                                                   [-x for x in besttt])
+            mindate = utils.addTimeTupleToDateTime(
+                minround, [-x for x in besttt])
             mintick = mindate
         deltamax = utils.datetimeToFloat(maxdate)-utils.datetimeToFloat(maxtick)
         if extendmax and (deltamax != 0. and deltamax < delta*0.15):
@@ -484,10 +495,12 @@ class DateTicks(AxisTicksBase):
             ticks.append( utils.datetimeToFloat(dt))
             dt = utils.addTimeTupleToDateTime(dt, besttt)
 
-        return ( utils.datetimeToFloat(mindate),
-                 utils.datetimeToFloat(maxdate),
-                 intervals_sec[best],
-                 N.array(ticks), format )
+        return (
+            utils.datetimeToFloat(mindate),
+            utils.datetimeToFloat(maxdate),
+            intervals_sec[best],
+            N.array(ticks), fmt
+        )
 
     def filterIntervals(self, estint):
         """Filter intervals and intervals_sec to be
@@ -506,7 +519,7 @@ class DateTicks(AxisTicksBase):
         """
 
         # find minor ticks
-        mindate, maxdate, est, ticks, format = self.bestTickFinder(
+        mindate, maxdate, est, ticks, fmt = self.bestTickFinder(
             self.minval, self.maxval, self.numticks,
             self.extendmin, self.extendmax,
             self.intervals, self.intervals_sec)
@@ -523,4 +536,4 @@ class DateTicks(AxisTicksBase):
         self.maxval = maxdate
         self.minorticks = minorticks
         self.tickvals = ticks
-        self.autoformat = format
+        self.autoformat = fmt
