@@ -19,11 +19,9 @@
 """Widget to plot axes, and to handle conversion of coordinates to plot
 positions."""
 
-from __future__ import division
 import numpy as N
 import re
 
-from ..compat import czip
 from .. import qtall as qt
 from .. import document
 from .. import setting
@@ -44,19 +42,21 @@ class MajorTick(setting.Line):
 
     def __init__(self, name, **args):
         setting.Line.__init__(self, name, **args)
-        self.add( setting.DistancePt( 'length',
-                                      '6pt',
-                                      descr = _('Length of major ticks'),
-                                      usertext= _('Length') ) )
-        self.add( setting.Int( 'number',
-                               6,
-                               descr = _('Number of major ticks to aim for'),
-                               usertext= _('Number') ) )
-        self.add( setting.FloatList('manualTicks',
-                                    [],
-                                    descr = _('List of tick values'
-                                              ' overriding defaults'),
-                                    usertext= _('Manual ticks') ) )
+        self.add( setting.DistancePt(
+            'length',
+            '6pt',
+            descr=_('Length of major ticks'),
+            usertext= _('Length') ) )
+        self.add( setting.Int(
+            'number',
+            6,
+            descr=_('Number of major ticks to aim for'),
+            usertext= _('Number') ) )
+        self.add( setting.FloatList(
+            'manualTicks',
+            [],
+            descr = _('List of tick values overriding defaults'),
+            usertext= _('Manual ticks') ) )
 
     def getLength(self, painter):
         '''Return tick length in painter coordinates'''
@@ -68,14 +68,21 @@ class MinorTick(setting.Line):
 
     def __init__(self, name, **args):
         setting.Line.__init__(self, name, **args)
-        self.add( setting.DistancePt( 'length',
-                                      '3pt',
-                                      descr = _('Length of minor ticks'),
-                                      usertext= _('Length')) )
-        self.add( setting.Int( 'number',
-                               20,
-                               descr = _('Number of minor ticks to aim for'),
-                               usertext= _('Number') ) )
+        self.add( setting.DistancePt(
+            'length',
+            '3pt',
+            descr=_('Length of minor ticks'),
+            usertext= _('Length')) )
+        self.add( setting.Int(
+            'number',
+            20,
+            descr=_('Number of minor ticks to aim for'),
+            usertext= _('Number') ) )
+        self.add( setting.FloatList(
+            'manualTicks',
+            [],
+            descr = _('List of tick values overriding defaults'),
+            usertext= _('Manual ticks') ) )
 
     def getLength(self, painter):
         '''Return tick length in painter coordinates'''
@@ -91,9 +98,10 @@ class GridLine(setting.Line):
         self.get('color').newDefault( 'grey' )
         self.get('hide').newDefault( True )
         self.get('style').newDefault( 'dotted' )
-        self.add( setting.Bool( 'onTop', False,
-                                descr = _('Put grid lines on top of graph'),
-                                usertext = _('On top') ) )
+        self.add( setting.Bool(
+            'onTop', False,
+            descr=_('Put grid lines on top of graph'),
+            usertext=_('On top') ) )
 
 class MinorGridLine(setting.Line):
     '''Minor tick grid line settings.'''
@@ -110,87 +118,117 @@ class AxisLabel(setting.Text):
 
     def __init__(self, name, **args):
         setting.Text.__init__(self, name, **args)
-        self.add( setting.Bool( 'atEdge', False,
-                                descr = _('Place axis label close to edge'
-                                          ' of graph'),
-                                usertext= _('At edge') ) )
+        self.add( setting.Bool(
+            'atEdge', False,
+            descr=_('Place axis label close to edge of graph'),
+            usertext= _('At edge') ) )
         self.add( setting.RotateInterval(
-                'rotate', '0',
-                descr = 'Angle by which to rotate label by',
-                usertext='Rotate') )
-        self.add( setting.DistancePt( 'offset',
-                                      '0pt',
-                                      descr = _('Additional offset of axis label'
-                                                ' from axis tick labels'),
-                                      usertext= _('Label offset') ) )
+            'rotate', '0',
+            descr='Angle by which to rotate label by',
+            usertext='Rotate') )
+        self.add( setting.DistancePt(
+            'offset',
+            '0pt',
+            descr=_('Additional offset of axis label from axis tick labels'),
+            usertext= _('Label offset') ) )
         self.add( setting.Choice(
-                'position',
-                ('at-minimum', 'centre', 'at-maximum'),
-                'centre',
-                descr = _('Position of axis label'),
-                usertext = _('Position') ) )
+            'position',
+            ('at-minimum', 'centre', 'at-maximum'),
+            'centre',
+            descr=_('Position of axis label'),
+            usertext = _('Position') ) )
 
 class TickLabel(setting.Text):
     """For tick labels on axes."""
 
-    formatchoices = ('Auto', '%Vg', '%Ve', '%VE',
-                     '%g', '%e', '%.2f')
-    descriptions = ( _('Automatic'),
-                     _('General numerical format'),
-                     _('Scientific notation'),
-                     _('Engineering suffix notation'),
-                     _('C-style general format'),
-                     _('C-style scientific notation'),
-                     _('2 decimal places always shown') )
+    formatchoices = ('Auto', '%Vg', '%Ve', '%VE', '%g', '%e', '%.2f')
+    descriptions = (
+        _('Automatic'),
+        _('General numerical format'),
+        _('Scientific notation'),
+        _('Engineering suffix notation'),
+        _('C-style general format'),
+        _('C-style scientific notation'),
+        _('2 decimal places always shown'),
+    )
 
     def __init__(self, name, **args):
         setting.Text.__init__(self, name, **args)
         self.add( setting.RotateInterval(
-                'rotate', '0',
-                descr = _('Angle by which to rotate label by'),
-                usertext= _('Rotate') ) )
-        self.add( setting.ChoiceOrMore( 'format',
-                                        TickLabel.formatchoices,
-                                        'Auto',
-                                        descr = _('Format of the tick labels'),
-                                        descriptions=TickLabel.descriptions,
-                                        usertext= _('Format') ) )
+            'rotate', '0',
+            descr=_('Angle by which to rotate label by'),
+            usertext= _('Rotate') ) )
+        self.add( setting.ChoiceOrMore(
+            'format',
+            TickLabel.formatchoices,
+            'Auto',
+            descr=_('Format of the tick labels'),
+            descriptions=TickLabel.descriptions,
+            usertext= _('Format') ) )
 
-        self.add( setting.Float('scale', 1.,
-                                descr=_('A scale factor to apply to the values '
-                                        'of the tick labels'),
-                                usertext=_('Scale') ) )
+        self.add( setting.Float(
+            'scale', 1.,
+            descr=_('A scale factor to apply to the values of the tick labels'),
+            usertext=_('Scale') ) )
 
-        self.add( setting.DistancePt( 'offset',
-                                      '0pt',
-                                      descr = _('Additional offset of axis tick '
-                                                'labels from axis'),
-                                      usertext= _('Tick offset') ) )
+        self.add( setting.DistancePt(
+            'offset',
+            '0pt',
+            descr = _('Additional offset of axis tick labels from axis'),
+            usertext= _('Tick offset') ) )
 
 class AutoRange(setting.ChoiceOrMore):
     """Choose how to choose range of axis."""
 
     # +5% or -5%
-    re_dr_plusminus = re.compile(r'^\s*([+-][0-9]+)\s*%\s*$')
+    re_dr_plusminus = re.compile(
+        r'''
+        ^\s*                        # start
+        ([+-][0-9]+(?:\.[0-9]+)?)   # +/- number (optional decimal)
+        \s*%                        # percent symbol
+        \s*$                        # end
+        ''', re.VERBOSE)
+
     # 5-10%
-    re_dr_percrange = re.compile(r'^\s*(-?[0-9]+)\s*-\s*([0-9]+)\s*%\s*$')
+    re_dr_percrange = re.compile(
+        r'''
+        ^\s*                    # start
+        (-?[0-9]+(?:\.[0-9]+)?) # 1st number
+        \s*-\s*                 # dash
+        ([0-9]+(?:\.[0-9]+)?)   # 2nd number
+        \s*%\s*$                # end
+        ''', re.VERBOSE)
+
     # < 5%
-    re_dr_lower = re.compile(r'^\s*<\s*([0-9]+)\s*%\s*$')
+    re_dr_lower = re.compile(
+        r'''
+        ^\s*<\s*                # start
+        ([0-9]+(?:\.[0-9]+)?)   # number
+        \s*%\s*$                # end
+        ''', re.VERBOSE)
+
     # > 95%
-    re_dr_upper = re.compile(r'^\s*>\s*([0-9]+)\s*%\s*$')
+    re_dr_upper = re.compile(
+        r'''
+        ^\s*>\s*                # start
+        ([0-9]+(?:\.[0-9]+)?)   # number
+        \s*%\s*$                # end
+        ''', re.VERBOSE)
 
     def __init__(self, name, value, **args):
         setting.ChoiceOrMore.__init__(
             self,
             'autoRange',
-            ('exact', 'next-tick',
-             '+2%', '+5%', '+10%', '+15%',
-             '-2%', '-5%', '-10%', '-15%',
-             '20-80%', '<20%', '>80%',
+            (
+                'exact', 'next-tick',
+                '+2%', '+5%', '+10%', '+15%',
+                '-2%', '-5%', '-10%', '-15%',
+                '20-80%', '<20%', '>80%',
             ),
             'next-tick',
-            descr = _('If axis range not specified, use range of '
-                      'data and this setting'),
+            descr = _(
+                'If axis range not specified, use range of '
+                'data and this setting'),
             descriptions = (
                 _('Use exact data range'),
                 _('Round up to tick marks from data range'),
@@ -208,7 +246,7 @@ class AutoRange(setting.ChoiceOrMore):
             ),
             formatting = True,
             usertext = _('Auto range'),
-            )
+        )
 
     def copy(self):
         """Return copy of this setting."""
@@ -266,8 +304,8 @@ class AutoRange(setting.ChoiceOrMore):
             origrange = list(plottedrange)
             if log:
                 # logarithmic
-                logrng = abs( N.log(plottedrange[1]) -
-                           N.log(plottedrange[0]) )
+                logrng = abs(
+                    N.log(plottedrange[1]) - N.log(plottedrange[0]) )
                 if adjustmin:
                     plottedrange[0] /= N.exp(logrng * expandfrac1)
                 if adjustmax:
@@ -318,109 +356,125 @@ class Axis(widget.Widget):
     def addSettings(klass, s):
         """Construct list of settings."""
         widget.Widget.addSettings(s)
-        s.add( setting.Str('label', '',
-                           descr=_('Axis label text'),
-                           usertext=_('Label')) )
-        s.add( setting.AxisBound('min', 'Auto',
-                                 descr=_('Minimum value of axis'),
-                                 usertext=_('Min')) )
-        s.add( setting.AxisBound('max', 'Auto',
-                                 descr=_('Maximum value of axis'),
-                                 usertext=_('Max')) )
-        s.add( setting.Bool('log', False,
-                            descr = _('Whether axis is logarithmic'),
-                            usertext=_('Log')) )
-        s.add( AutoRange('autoRange', 'next-tick') )
-        s.add( setting.Choice('mode',
-                              ('numeric', 'datetime', 'labels'),
-                              'numeric',
-                              descr = _('Type of ticks to show on on axis'),
-                              usertext=_('Mode')) )
+        s.add( setting.Str(
+            'label', '',
+            descr=_('Axis label text'),
+            usertext=_('Label')) )
+        s.add( setting.AxisBound(
+            'min', 'Auto',
+            descr=_('Minimum value of axis'),
+            usertext=_('Min')) )
+        s.add( setting.AxisBound(
+            'max', 'Auto',
+            descr=_('Maximum value of axis'),
+            usertext=_('Max')) )
+        s.add( setting.Bool(
+            'log', False,
+            descr=_('Whether axis is logarithmic'),
+            usertext=_('Log')) )
+        s.add( AutoRange(
+            'autoRange', 'next-tick') )
+        s.add( setting.Choice(
+            'mode',
+            ('numeric', 'datetime', 'labels'),
+            'numeric',
+            descr=_('Type of ticks to show on on axis'),
+            usertext=_('Mode')) )
 
         s.add( setting.SettingBackwardCompat(
-                'autoExtend', 'autoRange', True,
-                translatefn = lambda x: ('exact', 'next-tick')[x],
-                formatting=True ) )
+            'autoExtend', 'autoRange', True,
+            translatefn = lambda x: ('exact', 'next-tick')[x],
+            formatting=True ) )
 
         # this setting no longer used
-        s.add( setting.Bool('autoExtendZero', True,
-                            descr = _('Extend axis to zero if close (UNUSED)'),
-                            usertext=_('Zero extend'),
-                            hidden=True,
-                            formatting=True) )
+        s.add( setting.Bool(
+            'autoExtendZero', True,
+            descr=_('Extend axis to zero if close (UNUSED)'),
+            usertext=_('Zero extend'),
+            hidden=True,
+            formatting=True) )
 
-        s.add( setting.Bool('autoMirror', True,
-                            descr = _('Place axis on opposite side of graph '
-                                      'if none'),
-                            usertext=_('Auto mirror'),
-                            formatting=True) )
-        s.add( setting.Bool('reflect', False,
-                            descr = _('Place axis text and ticks on other side'
-                                      ' of axis'),
-                            usertext=_('Reflect'),
-                            formatting=True) )
-        s.add( setting.Bool('outerticks', False,
-                            descr = _('Place ticks on outside of graph'),
-                            usertext=_('Outer ticks'),
-                            formatting=True) )
+        s.add( setting.Bool(
+            'autoMirror', True,
+            descr=_('Place axis on opposite side of graph if none'),
+            usertext=_('Auto mirror'),
+            formatting=True) )
+        s.add( setting.Bool(
+            'reflect', False,
+            descr=_('Place axis text and ticks on other side of axis'),
+            usertext=_('Reflect'),
+            formatting=True) )
+        s.add( setting.Bool(
+            'outerticks', False,
+            descr=_('Place ticks on outside of graph'),
+            usertext=_('Outer ticks'),
+            formatting=True) )
 
-        s.add( setting.Float('datascale', 1.,
-                             descr=_('Scale data plotted by this factor'),
-                             usertext=_('Scale')) )
+        s.add( setting.Float(
+            'datascale', 1.,
+            descr=_('Scale data plotted by this factor'),
+            usertext=_('Scale')) )
 
-        s.add( setting.Choice('direction',
-                              ['horizontal', 'vertical'],
-                              'horizontal',
-                              descr = _('Direction of axis'),
-                              usertext=_('Direction')) )
-        s.add( setting.Float('lowerPosition', 0.,
-                             descr=_('Fractional position of lower end of '
-                                     'axis on graph'),
-                             usertext=_('Min position')) )
-        s.add( setting.Float('upperPosition', 1.,
-                             descr=_('Fractional position of upper end of '
-                                     'axis on graph'),
-                             usertext=_('Max position')) )
-        s.add( setting.Float('otherPosition', 0.,
-                             descr=_('Fractional position of axis '
-                                     'in its perpendicular direction'),
-                             usertext=_('Axis position')) )
+        s.add( setting.Choice(
+            'direction',
+            ['horizontal', 'vertical'],
+            'horizontal',
+            descr=_('Direction of axis'),
+            usertext=_('Direction')) )
+        s.add( setting.Float(
+            'lowerPosition', 0.,
+            descr=_('Fractional position of lower end of axis on graph'),
+            usertext=_('Min position')) )
+        s.add( setting.Float(
+            'upperPosition', 1.,
+            descr=_('Fractional position of upper end of axis on graph'),
+            usertext=_('Max position')) )
+        s.add( setting.Float(
+            'otherPosition', 0.,
+            descr=_('Fractional position of axis in its perpendicular direction'),
+            usertext=_('Axis position')) )
 
-        s.add( setting.WidgetPath('match', '',
-                                  descr =
-                                  _('Match the scale of this axis to the '
-                                    'axis specified'),
-                                  usertext=_('Match'),
-                                  allowedwidgets = [Axis] ))
+        s.add( setting.WidgetPath(
+            'match', '',
+            descr=_('Match the scale of this axis to the axis specified'),
+            usertext=_('Match'),
+            allowedwidgets=[Axis] ))
 
-        s.add( setting.Line('Line',
-                            descr = _('Axis line settings'),
-                            usertext = _('Axis line')),
-               pixmap='settings_axisline' )
-        s.add( AxisLabel('Label',
-                         descr = _('Axis label settings'),
-                         usertext = _('Axis label')),
-               pixmap='settings_axislabel' )
-        s.add( TickLabel('TickLabels',
-                         descr = _('Tick label settings'),
-                         usertext = _('Tick labels')),
-               pixmap='settings_axisticklabels' )
-        s.add( MajorTick('MajorTicks',
-                         descr = _('Major tick line settings'),
-                         usertext = _('Major ticks')),
-               pixmap='settings_axismajorticks' )
-        s.add( MinorTick('MinorTicks',
-                         descr = _('Minor tick line settings'),
-                         usertext = _('Minor ticks')),
-               pixmap='settings_axisminorticks' )
-        s.add( GridLine('GridLines',
-                        descr = _('Grid line settings'),
-                        usertext = _('Grid lines')),
-               pixmap='settings_axisgridlines' )
-        s.add( MinorGridLine('MinorGridLines',
-                             descr = _('Minor grid line settings'),
-                             usertext = _('Grid lines for minor ticks')),
-               pixmap='settings_axisminorgridlines' )
+        s.add( setting.Line(
+            'Line',
+            descr=_('Axis line settings'),
+            usertext=_('Axis line')),
+            pixmap='settings_axisline' )
+        s.add( AxisLabel(
+            'Label',
+            descr=_('Axis label settings'),
+            usertext=_('Axis label')),
+            pixmap='settings_axislabel' )
+        s.add( TickLabel(
+            'TickLabels',
+            descr=_('Tick label settings'),
+            usertext=_('Tick labels')),
+            pixmap='settings_axisticklabels' )
+        s.add( MajorTick(
+            'MajorTicks',
+            descr=_('Major tick line settings'),
+            usertext=_('Major ticks')),
+            pixmap='settings_axismajorticks' )
+        s.add( MinorTick(
+            'MinorTicks',
+            descr=_('Minor tick line settings'),
+            usertext=_('Minor ticks')),
+            pixmap='settings_axisminorticks' )
+        s.add( GridLine(
+            'GridLines',
+            descr=_('Grid line settings'),
+            usertext=_('Grid lines')),
+            pixmap='settings_axisgridlines' )
+        s.add( MinorGridLine(
+            'MinorGridLines',
+            descr=_('Minor grid line settings'),
+            usertext=_('Grid lines for minor ticks')),
+            pixmap='settings_axisminorgridlines' )
 
     @classmethod
     def allowedParentTypes(klass):
@@ -461,7 +515,6 @@ class Axis(widget.Widget):
         """Return whether any of the bounds are automatically determined."""
         return self.settings.min == 'Auto' or self.settings.max == 'Auto'
 
-
     def computePlottedRange(self, force=False, overriderange=None):
         """Convert the range requested into a plotted range."""
 
@@ -506,8 +559,8 @@ class Axis(widget.Widget):
         # line
         if ( abs(self.plottedrange[0] - self.plottedrange[1]) <
              ( abs(self.plottedrange[0]) + abs(self.plottedrange[1]) )*1e-12 ):
-               self.plottedrange[1] = ( self.plottedrange[0] +
-                                        max(1., self.plottedrange[0]*0.1) )
+            self.plottedrange[1] = (
+                self.plottedrange[0] + max(1., self.plottedrange[0]*0.1) )
 
         # handle axis values round the wrong way
         invertaxis = self.plottedrange[0] > self.plottedrange[1]
@@ -562,10 +615,12 @@ class Axis(widget.Widget):
         extendmax = nexttick and s.max == 'Auto' and allowauto
 
         # create object to compute ticks
-        axs = tickclass(self.plottedrange[0], self.plottedrange[1],
-                        s.MajorTicks.number, s.MinorTicks.number,
-                        extendmin = extendmin, extendmax = extendmax,
-                        logaxis = self.plottedLog())
+        axs = tickclass(
+            self.plottedrange[0], self.plottedrange[1],
+            s.MajorTicks.number, s.MinorTicks.number,
+            extendmin = extendmin, extendmax = extendmax,
+            logaxis = self.plottedLog()
+        )
 
         axs.getTicks()
         self.plottedrange[0] = axs.minval
@@ -582,6 +637,13 @@ class Axis(widget.Widget):
                     ticks.append(i)
             self.majortickscalc = N.array(ticks)
 
+        if len(s.MinorTicks.manualTicks) > 0:
+            ticks = []
+            for i in s.MinorTicks.manualTicks:
+                if i >= self.plottedrange[0] and i <= self.plottedrange[1]:
+                    ticks.append(i)
+            self.minortickscalc = N.array(ticks)
+
     def getPlottedRange(self):
         """Return the range plotted by the axes."""
         self.computePlottedRange()
@@ -673,8 +735,10 @@ class Axis(widget.Widget):
         self.updateAxisLocation( bounds )
 
         # work out fractional positions of the plotter coords
-        frac = ( (vals.astype(N.float64) - self.coordParr1) /
-                 (self.coordParr2 - self.coordParr1) )
+        frac = (
+            (vals.astype(N.float64) - self.coordParr1) /
+            (self.coordParr2 - self.coordParr1)
+        )
 
         # convert from fractional to graph
         if self.plottedLog():
@@ -693,14 +757,18 @@ class Axis(widget.Widget):
     def linearConvertToPlotter(self, v):
         """Convert graph coordinates to fractional plotter units for linear scale.
         """
-        return ( (v - self.plottedrange[0]) /
-                 (self.plottedrange[1] - self.plottedrange[0]) )
+        return (
+            (v - self.plottedrange[0]) /
+            (self.plottedrange[1] - self.plottedrange[0])
+        )
 
     def linearConvertFromPlotter(self, v):
         """Convert from (fractional) plotter coords to graph coords.
         """
-        return ( self.plottedrange[0] + v *
-                 (self.plottedrange[1]-self.plottedrange[0]) )
+        return (
+            self.plottedrange[0] + v *
+            (self.plottedrange[1]-self.plottedrange[0])
+        )
 
     def logConvertToPlotter(self, v):
         """Convert graph coordinates to fractional plotter units for log10 scale.
@@ -713,8 +781,10 @@ class Axis(widget.Widget):
     def logConvertFromPlotter(self, v):
         """Convert from fraction plotter coords to graph coords with log scale.
         """
-        return ( self.plottedrange[0] *
-                 ( self.plottedrange[1]/self.plottedrange[0] )**v )
+        return (
+            self.plottedrange[0] *
+            ( self.plottedrange[1]/self.plottedrange[0] )**v
+        )
 
     def againstWhichEdge(self):
         """Returns edge this axis is against, if any.
@@ -761,16 +831,20 @@ class Axis(widget.Widget):
         if self.parent.typename == 'graph':
             if not self.parent.settings.Border.hide:
                 if self.settings.direction == 'horizontal':
-                    ok = ( (N.abs(coordticks-parentposn[0]) > 1e-3) &
-                           (N.abs(coordticks-parentposn[2]) > 1e-3) )
+                    ok = (
+                        (N.abs(coordticks-parentposn[0]) > 1e-3) &
+                        (N.abs(coordticks-parentposn[2]) > 1e-3) )
                 else:
-                    ok = ( (N.abs(coordticks-parentposn[1]) > 1e-3) &
-                           (N.abs(coordticks-parentposn[3]) > 1e-3) )
+                    ok = (
+                        (N.abs(coordticks-parentposn[1]) > 1e-3) &
+                        (N.abs(coordticks-parentposn[3]) > 1e-3) )
                 coordticks = coordticks[ok]
 
-        self.swaplines(painter,
-                       coordticks, coordticks*0.+self.coordPerp1,
-                       coordticks, coordticks*0.+self.coordPerp2)
+        self.swaplines(
+            painter,
+            coordticks, coordticks*0.+self.coordPerp1,
+            coordticks, coordticks*0.+self.coordPerp2
+        )
 
     def _drawAxisLine(self, painter, posn):
         """Draw the line of the axis."""
@@ -778,9 +852,11 @@ class Axis(widget.Widget):
         pen = self.settings.get('Line').makeQPen(painter)
         pen.setCapStyle(qt.Qt.FlatCap)
         painter.setPen(pen)
-        self.swapline( painter,
-                       self.coordParr1, self.coordPerp,
-                       self.coordParr2, self.coordPerp )
+        self.swapline(
+            painter,
+            self.coordParr1, self.coordPerp,
+            self.coordParr2, self.coordPerp
+        )
 
     def _drawMinorTicks(self, painter, coordminorticks):
         """Draw minor ticks on plot."""
@@ -800,9 +876,11 @@ class Axis(widget.Widget):
             delta *= -1
 
         y = coordminorticks*0.+self.coordPerp
-        self.swaplines( painter,
-                        coordminorticks, y,
-                        coordminorticks, y-delta )
+        self.swaplines(
+            painter,
+            coordminorticks, y,
+            coordminorticks, y-delta
+        )
 
     def _drawMajorTicks(self, painter, tickcoords):
         """Draw major ticks on the plot."""
@@ -823,9 +901,11 @@ class Axis(widget.Widget):
             delta *= -1
 
         y = tickcoords*0.+self.coordPerp
-        self.swaplines( painter,
-                        tickcoords, y,
-                        tickcoords, y-delta )
+        self.swaplines(
+            painter,
+            tickcoords, y,
+            tickcoords, y-delta
+        )
 
         # account for ticks if they are in the direction of the label
         if s.outerticks and not self.coordReflected:
@@ -847,7 +927,7 @@ class Axis(widget.Widget):
             if labels is not None and coords is not None:
                 # convert coordinates to plotter coordinates
                 pcoords = self._graphToPlotter(coords)
-                for coord, pcoord, lab in czip(coords, pcoords, labels):
+                for coord, pcoord, lab in zip(coords, pcoords, labels):
                     # return labels that are within the plotted range
                     # of coordinates
                     if N.isfinite(coord) and (minval <= coord <= maxval):
@@ -898,9 +978,9 @@ class Axis(widget.Widget):
                 format = self.autoformat
 
             # generate positions and labels
-            for posn, tickval in czip(coordticks, tickvals):
-                text = utils.formatNumber(tickval*scale, format,
-                                          locale=self.document.locale)
+            for posn, tickval in zip(coordticks, tickvals):
+                text = utils.formatNumber(
+                    tickval*scale, format, locale=self.document.locale)
                 yield posn, text
 
         # position of label perpendicular to axis
@@ -930,11 +1010,13 @@ class Axis(widget.Widget):
             if outerbounds is not None:
                 # make sure ticks are within plot
                 if vertical:
-                    r.ensureInBox(miny=outerbounds[1], maxy=outerbounds[3],
-                                  extraspace=True)
+                    r.ensureInBox(
+                        miny=outerbounds[1], maxy=outerbounds[3],
+                        extraspace=True)
                 else:
-                    r.ensureInBox(minx=outerbounds[0], maxx=outerbounds[2],
-                                  extraspace=True)
+                    r.ensureInBox(
+                        minx=outerbounds[0], maxx=outerbounds[2],
+                        extraspace=True)
 
             bnd = r.getBounds()
             texttorender.append( (r, pen) )
@@ -974,9 +1056,11 @@ class Axis(widget.Widget):
         horz = s.direction == 'horizontal'
 
         align1 = 1
-        align2 = {'centre': 0,
-                  'at-minimum': -1,
-                  'at-maximum': 1}[sl.position]
+        align2 = {
+            'centre': 0,
+            'at-minimum': -1,
+            'at-maximum': 1
+        }[sl.position]
 
         if horz:
             ax, ay = align2, align1
@@ -1038,8 +1122,10 @@ class Axis(widget.Widget):
 
         # make sure text is in plot rectangle
         if outerbounds is not None:
-            r.ensureInBox( minx=outerbounds[0], maxx=outerbounds[2],
-                           miny=outerbounds[1], maxy=outerbounds[3] )
+            r.ensureInBox(
+                minx=outerbounds[0], maxx=outerbounds[2],
+                miny=outerbounds[1], maxy=outerbounds[3]
+            )
 
         texttorender.insert(0, (r, s.get('Label').makeQPen(painter)) )
 
@@ -1066,8 +1152,9 @@ class Axis(widget.Widget):
             return False
 
         s = self.settings
-        height = utils.FontMetrics( s.get('Label').makeQFont(painter),
-                                    painter.device()).height()
+        height = utils.FontMetrics(
+            s.get('Label').makeQFont(painter),
+            painter.device()).height()
         otherposition = s.otherPosition
 
         if s.direction == 'vertical':
@@ -1110,12 +1197,14 @@ class Axis(widget.Widget):
 
             if not s.MinorGridLines.hide:
                 coordminorticks = self._graphToPlotter(self.minortickscalc)
-                self._drawGridLines('MinorGridLines', painter, coordminorticks,
-                                    parentposn)
+                self._drawGridLines(
+                    'MinorGridLines', painter, coordminorticks,
+                    parentposn)
             if not s.GridLines.hide:
                 coordticks = self._graphToPlotter(self.majortickscalc)
-                self._drawGridLines('GridLines', painter, coordticks,
-                                    parentposn)
+                self._drawGridLines(
+                    'GridLines', painter, coordticks,
+                    parentposn)
 
             painter.restore()
 
@@ -1238,8 +1327,9 @@ class Axis(widget.Widget):
         # plot tick labels
         suppresstext = self._suppressText(painter, parentposn, outerbounds)
         if not s.TickLabels.hide and not suppresstext:
-            self._drawTickLabels(phelper, painter, coordticks, sign,
-                                 outerbounds, self.majortickscalc, texttorender)
+            self._drawTickLabels(
+                phelper, painter, coordticks, sign,
+                outerbounds, self.majortickscalc, texttorender)
 
         # draw an axis label
         if not s.Label.hide and not suppresstext:
@@ -1294,11 +1384,11 @@ class Axis(widget.Widget):
             if ( (s.min == 'Auto' or not N.allclose(c1, s.min, rtol=1e-8))
                  and N.isfinite(round1) ):
                 ops.append( document.OperationSettingSet(
-                        s.get('min'), round1) )
+                    s.get('min'), round1) )
             if ( (s.max == 'Auto' or not N.allclose(c2, s.max, rtol=1e-8))
                  and N.isfinite(round2) ):
                 ops.append( document.OperationSettingSet(
-                        s.get('max'), round2) )
+                    s.get('max'), round2) )
 
             self.document.applyOperation(
                 document.OperationMultiple(ops, descr=_('zoom axis')))
@@ -1306,8 +1396,9 @@ class Axis(widget.Widget):
         elif cgi.moved():
             # move axis
             # convert positions to fractions
-            pt1, pt2, ppt1, ppt2 = ( (3, 1, 0, 2), (0, 2, 3, 1)
-                                     ) [s.direction == 'horizontal']
+            pt1, pt2, ppt1, ppt2 = (
+                (3, 1, 0, 2), (0, 2, 3, 1)
+            )[s.direction == 'horizontal']
             minfrac = abs((cgi.minpos - p[pt1]) / (p[pt2] - p[pt1]))
             maxfrac = abs((cgi.maxpos - p[pt1]) / (p[pt2] - p[pt1]))
             axisfrac = abs((cgi.axispos - p[ppt1]) / (p[ppt2] - p[ppt1]))
@@ -1320,15 +1411,15 @@ class Axis(widget.Widget):
             ops = []
             if s.lowerPosition != minfrac:
                 ops.append( document.OperationSettingSet(
-                        s.get('lowerPosition'), round(minfrac, 3)) )
+                    s.get('lowerPosition'), round(minfrac, 3)) )
             if s.upperPosition != maxfrac:
                 ops.append( document.OperationSettingSet(
-                        s.get('upperPosition'), round(maxfrac, 3)) )
+                    s.get('upperPosition'), round(maxfrac, 3)) )
             if s.otherPosition != axisfrac:
                 ops.append( document.OperationSettingSet(
-                        s.get('otherPosition'), round(axisfrac, 3)) )
+                    s.get('otherPosition'), round(axisfrac, 3)) )
             self.document.applyOperation(
                 document.OperationMultiple(ops, descr=_('adjust axis')))
 
 # allow the factory to instantiate an axis
-document.thefactory.register( Axis )
+document.thefactory.register(Axis)
