@@ -18,10 +18,8 @@
 
 """For plotting xy points."""
 
-from __future__ import division
 import numpy as N
 
-from ..compat import czip
 from .. import qtall as qt
 from .. import datasets
 from .. import document
@@ -31,85 +29,119 @@ from .. import utils
 from . import pickable
 from .plotters import GenericPlotter
 
-try:
-    from ..helpers import qtloops
-    hasqtloops = True
-except ImportError:
-    hasqtloops = False
+from ..helpers import qtloops
 
 def _(text, disambiguation=None, context='XY'):
     """Translate text."""
     return qt.QCoreApplication.translate(context, text, disambiguation)
 
-# functions for plotting error bars
-# different styles are made up of combinations of these functions
-# each function takes the same arguments
-def _errorBarsBar(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                  s, painter, clip):
-    """Draw bar style error lines."""
-    # vertical error bars
-    if ymin is not None and ymax is not None and not s.ErrorBarLine.hideVert:
-        utils.plotLinesToPainter(painter, xplotter, ymin, xplotter, ymax, clip)
+class ErrorBarDraw:
+    """For plotting error bars."""
 
-    # horizontal error bars
-    if xmin is not None and xmax is not None and not s.ErrorBarLine.hideHorz:
-        utils.plotLinesToPainter(painter, xmin, yplotter, xmax, yplotter, clip)
+    def __init__(self, style, linestyle, fillabove, fillbelow, markersize):
+        self.style = style
+        self.linestyle = linestyle
+        self.fillabove = fillabove
+        self.fillbelow = fillbelow
+        self.markersize = markersize
 
-def _errorBarsEnds(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                   s, painter, clip):
-    """Draw perpendiclar ends on error bars."""
-    size = ( s.get('markerSize').convert(painter) *
-             s.ErrorBarLine.endsize )
+    def plot(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        pen = self.linestyle.makeQPenWHide(painter)
+        pen.setCapStyle(qt.Qt.FlatCap)
 
-    if ymin is not None and ymax is not None and not s.ErrorBarLine.hideVert:
-        utils.plotLinesToPainter(
-            painter, xplotter-size, ymin,
-            xplotter+size, ymin, clip)
-        utils.plotLinesToPainter(
-            painter, xplotter-size, ymax,
-            xplotter+size, ymax, clip)
+        painter.setPen(pen)
+        for function in self.error_functions[self.style]:
+            function(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip)
 
-    if xmin is not None and xmax is not None and not s.ErrorBarLine.hideHorz:
-        utils.plotLinesToPainter(
-            painter, xmin, yplotter-size,
-            xmin, yplotter+size, clip)
-        utils.plotLinesToPainter(
-            painter, xmax, yplotter-size,
-            xmax, yplotter+size, clip)
+    def errorsBar(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw bar style error lines."""
+        # vertical error bars
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(painter, xplt, ymin, xplt, ymax, clip)
 
-def _errorBarsBox(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                  s, painter, clip):
-    """Draw box around error region."""
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
-        painter.setBrush( qt.QBrush() )
-        utils.plotBoxesToPainter(painter, xmin, ymin, xmax, ymax, clip)
+        # horizontal error bars
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(painter, xmin, yplt, xmax, yplt, clip)
+
+    def errorsBarHi(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw bar style error lines (top half only)."""
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(painter, xplt, yplt, xplt, ymax, clip)
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(painter, xplt, yplt, xmax, yplt, clip)
+
+    def errorsBarLo(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw bar style error lines (bottom half only)."""
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(painter, xplt, yplt, xplt, ymin, clip)
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(painter, xplt, yplt, xmin, yplt, clip)
+
+    def errorsEnds(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw perpendiclar ends on error bars."""
+        size = self.markersize * self.linestyle.endsize
+
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(
+                painter, xplt-size, ymin, xplt+size, ymin, clip)
+            qtloops.plotLinesToPainter(
+                painter, xplt-size, ymax, xplt+size, ymax, clip)
+
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(
+                painter, xmin, yplt-size, xmin, yplt+size, clip)
+            qtloops.plotLinesToPainter(
+                painter, xmax, yplt-size, xmax, yplt+size, clip)
+
+    def errorsEndsHi(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw perpendiclar ends on error bars (top half only)."""
+        size = self.markersize * self.linestyle.endsize
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(
+                painter, xplt-size, ymax, xplt+size, ymax, clip)
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(
+                painter, xmax, yplt-size, xmax, yplt+size, clip)
+
+    def errorsEndsLo(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw perpendiclar ends on error bars (bottom half only)."""
+        size = self.markersize * self.linestyle.endsize
+        if ymin is not None and ymax is not None and not self.linestyle.hideVert:
+            qtloops.plotLinesToPainter(
+                painter, xplt-size, ymin, xplt+size, ymin, clip)
+        if xmin is not None and xmax is not None and not self.linestyle.hideHorz:
+            qtloops.plotLinesToPainter(
+                painter, xmin, yplt-size, xmin, yplt+size, clip)
+
+    def errorsBox(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw box around error region."""
+        if utils.allNotNone(xmin, xmax, ymin, ymax):
+            painter.setBrush(qt.QBrush())
+            qtloops.plotBoxesToPainter(painter, xmin, ymin, xmax, ymax, clip)
+
+    def errorsBoxFilled(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw box filled region inside error bars."""
+        if utils.anyNone(xmin, xmax, ymin, ymax):
+            return
 
-def _errorBarsBoxFilled(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                        s, painter, clip):
-    """Draw box filled region inside error bars."""
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
         # filled region below
-        if not s.FillBelow.hideerror:
+        if not self.fillbelow.hideerror:
             path = qt.QPainterPath()
-            utils.addNumpyPolygonToPath(
-                path, clip,
-                xmin, ymin, xmin, yplotter,
-                xmax, yplotter, xmax, ymin)
-            utils.brushExtFillPath(painter, s.FillBelow, path, ignorehide=True)
+            qtloops.addNumpyPolygonToPath(
+                path, clip, xmin, ymin, xmin, yplt, xmax, yplt, xmax, ymin)
+            utils.brushExtFillPath(painter, self.fillbelow, path, ignorehide=True)
 
         # filled region above
-        if not s.FillAbove.hideerror:
+        if not self.fillabove.hideerror:
             path = qt.QPainterPath()
-            utils.addNumpyPolygonToPath(
-                path, clip,
-                xmin, yplotter, xmax, yplotter,
-                xmax, ymax, xmin, ymax)
-            utils.brushExtFillPath(painter, s.FillAbove, path, ignorehide=True)
+            qtloops.addNumpyPolygonToPath(
+                path, clip, xmin, yplt, xmax, yplt, xmax, ymax, xmin, ymax)
+            utils.brushExtFillPath(painter, self.fillabove, path, ignorehide=True)
 
-def _errorBarsDiamond(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                      s, painter, clip):
-    """Draw diamond around error region."""
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
+    def errorsDiamond(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw diamond around error region."""
+        if utils.anyNone(xmin, xmax, ymin, ymax):
+            return
 
         # expand clip by pen width (urgh)
         pw = painter.pen().widthF()*2
@@ -118,155 +150,152 @@ def _errorBarsDiamond(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
             qt.QPointF(clip.right()+pw,clip.bottom()+pw))
 
         path = qt.QPainterPath()
-        utils.addNumpyPolygonToPath(
-            path, clip,
-            xmin, yplotter, xplotter, ymax,
-            xmax, yplotter, xplotter, ymin)
+        qtloops.addNumpyPolygonToPath(
+            path, clip, xmin, yplt, xplt, ymax, xmax, yplt, xplt, ymin)
         painter.setBrush( qt.QBrush() )
         painter.drawPath(path)
 
-def _errorBarsDiamondFilled(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                            s, painter, clip):
-    """Draw diamond filled region inside error bars."""
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
-        if not s.FillBelow.hideerror:
-            path = qt.QPainterPath()
-            utils.addNumpyPolygonToPath(
-                path, clip,
-                xmin, yplotter, xplotter, ymin,
-                xmax, yplotter)
-            utils.brushExtFillPath(painter, s.FillBelow, path, ignorehide=True)
+    def errorsDiamondFilled(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw diamond filled region inside error bars."""
+        if utils.anyNone(xmin, xmax, ymin, ymax):
+            return
 
-        if not s.FillAbove.hideerror:
+        if not self.fillbelow.hideerror:
             path = qt.QPainterPath()
-            utils.addNumpyPolygonToPath(
-                path, clip,
-                xmin, yplotter, xplotter, ymax,
-                xmax, yplotter)
-            utils.brushExtFillPath(painter, s.FillAbove, path, ignorehide=True)
+            qtloops.addNumpyPolygonToPath(
+                path, clip, xmin, yplt, xplt, ymin, xmax, yplt)
+            utils.brushExtFillPath(painter, self.fillbelow, path, ignorehide=True)
+
+        if not self.fillabove.hideerror:
+            path = qt.QPainterPath()
+            qtloops.addNumpyPolygonToPath(
+                path, clip, xmin, yplt, xplt, ymax, xmax, yplt)
+            utils.brushExtFillPath(painter, self.fillabove, path, ignorehide=True)
+
+    def errorsCurve(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw curve around error region."""
+        if utils.anyNone(xmin, xmax, ymin, ymax):
+            return
 
-def _errorBarsCurve(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                    s, painter, clip):
-    """Draw curve around error region."""
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
         # non-filling brush
         painter.setBrush( qt.QBrush() )
 
-        for xp, yp, xmn, ymn, xmx, ymx in czip(
-            xplotter, yplotter, xmin, ymin, xmax, ymax):
-
+        for xp, yp, xmn, ymn, xmx, ymx in zip(xplt, yplt, xmin, ymin, xmax, ymax):
             p = qt.QPainterPath()
             p.moveTo(xp + (xmx-xp), yp)
             p.arcTo(qt.QRectF(
-                xp - (xmx-xp), yp - (yp-ymx),
-                (xmx-xp)*2, (yp-ymx)*2), 0., 90.)
+                xp - (xmx-xp), yp - (yp-ymx), (xmx-xp)*2, (yp-ymx)*2), 0., 90.)
             p.arcTo(qt.QRectF(
-                xp - (xp-xmn), yp - (yp-ymx),
-                (xp-xmn)*2, (yp-ymx)*2), 90., 90.)
+                xp - (xp-xmn), yp - (yp-ymx), (xp-xmn)*2, (yp-ymx)*2), 90., 90.)
             p.arcTo(qt.QRectF(
-                xp - (xp-xmn), yp - (ymn-yp),
-                (xp-xmn)*2, (ymn-yp)*2), 180., 90.)
+                xp - (xp-xmn), yp - (ymn-yp), (xp-xmn)*2, (ymn-yp)*2), 180., 90.)
             p.arcTo(qt.QRectF(
-                xp - (xmx-xp), yp - (ymn-yp),
-                (xmx-xp)*2, (ymn-yp)*2), 270., 90.)
+                xp - (xmx-xp), yp - (ymn-yp), (xmx-xp)*2, (ymn-yp)*2), 270., 90.)
             painter.drawPath(p)
 
-def _errorBarsCurveFilled(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                          s, painter, clip):
-    """Fill area around error region."""
+    def errorsCurveFilled(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Fill area around error region."""
 
-    if utils.allNotNone(xmin, xmax, ymin, ymax):
-        for xp, yp, xmn, ymn, xmx, ymx in czip(
-            xplotter, yplotter, xmin, ymin, xmax, ymax):
+        if utils.anyNone(xmin, xmax, ymin, ymax):
+            return
 
-            if not s.FillAbove.hideerror:
+        for xp, yp, xmn, ymn, xmx, ymx in zip(xplt, yplt, xmin, ymin, xmax, ymax):
+
+            if not self.fillabove.hideerror:
                 p = qt.QPainterPath()
                 p.moveTo(xp + (xmx-xp), yp)
                 p.arcTo(qt.QRectF(
-                    xp - (xmx-xp), yp - (yp-ymx),
-                    (xmx-xp)*2, (yp-ymx)*2), 0., 90.)
+                    xp - (xmx-xp), yp - (yp-ymx), (xmx-xp)*2, (yp-ymx)*2), 0., 90.)
                 p.arcTo(qt.QRectF(
-                    xp - (xp-xmn), yp - (yp-ymx),
-                    (xp-xmn)*2, (yp-ymx)*2), 90., 90.)
-                utils.brushExtFillPath(painter, s.FillAbove, p, ignorehide=True)
+                    xp - (xp-xmn), yp - (yp-ymx), (xp-xmn)*2, (yp-ymx)*2), 90., 90.)
+                utils.brushExtFillPath(painter, self.fillabove, p, ignorehide=True)
 
-            if not s.FillBelow.hideerror:
+            if not self.fillbelow.hideerror:
                 p = qt.QPainterPath()
                 p.moveTo(xp + (xp-xmn), yp)
                 p.arcTo(qt.QRectF(
-                    xp - (xp-xmn), yp - (ymn-yp),
-                    (xp-xmn)*2, (ymn-yp)*2), 180., 90.)
+                    xp - (xp-xmn), yp - (ymn-yp), (xp-xmn)*2, (ymn-yp)*2), 180., 90.)
                 p.arcTo(qt.QRectF(
-                    xp - (xmx-xp), yp - (ymn-yp),
-                    (xmx-xp)*2, (ymn-yp)*2), 270., 90.)
-                utils.brushExtFillPath(painter, s.FillBelow, p, ignorehide=True)
+                    xp - (xmx-xp), yp - (ymn-yp), (xmx-xp)*2, (ymn-yp)*2), 270., 90.)
+                utils.brushExtFillPath(painter, self.fillbelow, p, ignorehide=True)
 
-def _errorBarsFilled(style, xmin, xmax, ymin, ymax, xplotter, yplotter,
-                     s, painter, clip):
-    """Draw filled region as error region."""
+    def errorsFilled(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
+        """Draw filled region as error region."""
 
-    ptsabove = qt.QPolygonF()
-    ptsbelow = qt.QPolygonF()
+        ptsabove = qt.QPolygonF()
+        ptsbelow = qt.QPolygonF()
 
-    hidevert = True  # keep track of what's shown
-    hidehorz = True
-    if ( 'vert' in style and
-         (ymin is not None and ymax is not None) and
-         not s.ErrorBarLine.hideVert ):
-        hidevert = False
-        # lines above/below points
-        utils.addNumpyToPolygonF(ptsbelow, xplotter, ymin)
-        utils.addNumpyToPolygonF(ptsabove, xplotter, ymax)
+        hidevert = True  # keep track of what's shown
+        hidehorz = True
+        if ( 'vert' in self.style and
+             (ymin is not None and ymax is not None) and
+             not self.linestyle.hideVert ):
+            hidevert = False
+            # lines above/below points
+            if self.style[-2:] != 'hi':
+                qtloops.addNumpyToPolygonF(ptsbelow, xplt, ymin)
+            if self.style[-2:] != 'lo':
+                qtloops.addNumpyToPolygonF(ptsabove, xplt, ymax)
 
-    elif ( 'horz' in style and
-           (xmin is not None and xmax is not None) and
-           not s.ErrorBarLine.hideHorz ):
-        hidehorz = False
-        # lines left/right points
-        utils.addNumpyToPolygonF(ptsbelow, xmin, yplotter)
-        utils.addNumpyToPolygonF(ptsabove, xmax, yplotter)
+        elif ( 'horz' in self.style and
+               (xmin is not None and xmax is not None) and
+               not self.linestyle.hideHorz ):
+            hidehorz = False
+            # lines left/right points
+            if self.style[-2:] != 'hi':
+                qtloops.addNumpyToPolygonF(ptsbelow, xmin, yplt)
+            if self.style[-2:] != 'lo':
+                qtloops.addNumpyToPolygonF(ptsabove, xmax, yplt)
 
-    # draw filled regions above/left and below/right
-    if 'fill' in style and not (hidehorz and hidevert):
-        # construct points for error bar regions
-        retnpts = qt.QPolygonF()
-        utils.addNumpyToPolygonF(retnpts, xplotter[::-1], yplotter[::-1])
+        # draw filled regions above/left and below/right
+        if 'fill' in self.style and not (hidehorz and hidevert):
+            # construct points for error bar regions
+            retnpts = qt.QPolygonF()
+            qtloops.addNumpyToPolygonF(retnpts, xplt[::-1], yplt[::-1])
 
-        # polygons consist of lines joining the points and continuing
-        # back along the plot line (retnpts)
-        if not s.FillBelow.hideerror:
-            utils.brushExtFillPolygon(
-                painter, s.FillBelow, clip,
-                ptsbelow+retnpts, ignorehide=True)
-        if not s.FillAbove.hideerror:
-            utils.brushExtFillPolygon(
-                painter, s.FillAbove, clip,
-                ptsabove+retnpts, ignorehide=True)
+            # polygons consist of lines joining the points and continuing
+            # back along the plot line (retnpts)
+            if not self.fillbelow.hideerror and ptsbelow:
+                utils.brushExtFillPolygon(
+                    painter, self.fillbelow, clip, ptsbelow+retnpts, ignorehide=True)
+            if not self.fillabove.hideerror and ptsabove:
+                utils.brushExtFillPolygon(
+                    painter, self.fillabove, clip, ptsabove+retnpts, ignorehide=True)
 
-    # draw optional line (on top of fill)
-    utils.plotClippedPolyline(painter, clip, ptsabove)
-    utils.plotClippedPolyline(painter, clip, ptsbelow)
+        # draw optional line (on top of fill)
+        if ptsabove:
+            qtloops.plotClippedPolyline(painter, clip, ptsabove)
+        if ptsbelow:
+            qtloops.plotClippedPolyline(painter, clip, ptsbelow)
 
-# map error bar names to lists of functions (above)
-_errorBarFunctionMap = {
-    'none': (),
-    'bar': (_errorBarsBar,),
-    'bardiamond': (_errorBarsBar, _errorBarsDiamond,),
-    'barcurve': (_errorBarsBar, _errorBarsCurve,),
-    'barbox': (_errorBarsBar, _errorBarsBox,),
-    'barends': (_errorBarsBar, _errorBarsEnds,),
-    'box':  (_errorBarsBox,),
-    'boxfill': (_errorBarsBoxFilled, _errorBarsBox,),
-    'diamond':  (_errorBarsDiamond,),
-    'diamondfill':  (_errorBarsDiamond, _errorBarsDiamondFilled),
-    'curve': (_errorBarsCurve,),
-    'curvefill': (_errorBarsCurveFilled, _errorBarsCurve,),
-    'fillhorz': (_errorBarsFilled,),
-    'fillvert': (_errorBarsFilled,),
-    'linehorz': (_errorBarsFilled,),
-    'linevert': (_errorBarsFilled,),
-    'linehorzbar': (_errorBarsBar, _errorBarsFilled),
-    'linevertbar': (_errorBarsBar, _errorBarsFilled),
+    # map error bar names to lists of functions (above)
+    error_functions = {
+        'none': (),
+        'bar': (errorsBar,),
+        'bardiamond': (errorsBar, errorsDiamond,),
+        'barcurve': (errorsBar, errorsCurve,),
+        'barbox': (errorsBar, errorsBox,),
+        'barends': (errorsBar, errorsEnds,),
+        'box':  (errorsBox,),
+        'boxfill': (errorsBoxFilled, errorsBox,),
+        'diamond':  (errorsDiamond,),
+        'diamondfill':  (errorsDiamond, errorsDiamondFilled),
+        'curve': (errorsCurve,),
+        'curvefill': (errorsCurveFilled, errorsCurve,),
+        'fillhorz': (errorsFilled,),
+        'fillvert': (errorsFilled,),
+        'linehorz': (errorsFilled,),
+        'linevert': (errorsFilled,),
+        'linehorzbar': (errorsBar, errorsFilled),
+        'linevertbar': (errorsBar, errorsFilled),
+        'barhi': (errorsBarHi,),
+        'barlo': (errorsBarLo,),
+        'barendshi': (errorsBarHi, errorsEndsHi,),
+        'barendslo': (errorsBarLo, errorsEndsLo,),
+        'linehorzlo': (errorsFilled,),
+        'linehorzhi': (errorsFilled,),
+        'linevertlo': (errorsFilled,),
+        'lineverthi': (errorsFilled,),
     }
 
 def fillPtsToEdge(painter, pts, posn, cliprect, fillstyle):
@@ -301,14 +330,20 @@ class MarkerFillBrush(setting.Brush):
 
         self.add( setting.Colormap(
             'colorMap', 'grey',
-            descr = _('If color markers dataset is given, use this colormap '
-                      'instead of the fill color'),
+            descr=_(
+                'If color markers dataset is given, use this colormap '
+                'instead of the fill color'),
             usertext=_('Color map'),
             formatting=True) )
         self.add( setting.Bool(
             'colorMapInvert', False,
-            descr = _('Invert color map'),
-            usertext = _('Invert map'),
+            descr=_('Invert color map'),
+            usertext=_('Invert map'),
+            formatting=True) )
+        self.add( setting.Bool(
+            'newMarkerSizes', False,
+            descr=_('Use new marker sizes with equal area'),
+            usertext=_('New marker sizes'),
             formatting=True) )
 
 class PointPlotter(GenericPlotter):
@@ -335,12 +370,24 @@ class PointPlotter(GenericPlotter):
         s.add( setting.DatasetOrStr(
             'labels', '',
             descr=_('Dataset or string to label points'),
-            usertext=_('Labels')), 5 )
+            usertext=_('Labels')), 6 )
         s.add( setting.DatasetExtended(
             'scalePoints', '',
-            descr = _('Scale size of markers given by dataset, expression'
-                      ' or list of values'),
-            usertext=_('Scale markers')), 6 )
+            descr=_(
+                'Scale size of markers given by dataset, expression'
+                ' or list of values'),
+            usertext=_('Scale markers')), 7 )
+        s.add( setting.DataColor('Color'), 8 )
+        s.add( setting.Choice(
+            'nanHandling',
+            ('break-on', 'ignore'),
+            'break-on',
+            descr=_('Effect of NaN values in input datasets'),
+            usertext=_('NaN handling'),
+            descriptions=(
+                _('NaN values are used to break datasets into parts at their locations'),
+                _('NaN values cause data in their locations to be ignored'),
+            )), 9 )
 
         # formatting
         s.add( setting.Int(
@@ -352,27 +399,27 @@ class PointPlotter(GenericPlotter):
         s.add( setting.Int(
             'thinfactor', 1,
             minval=1,
-            descr=_('Thin number of markers plotted'
-                    ' for each datapoint by this factor'),
+            descr=_(
+                'Thin number of markers plotted for each datapoint '
+                'by this factor'),
             usertext=_('Thin markers'),
             formatting=True), 0 )
         s.add( setting.Color(
             'color',
             'auto',
-            descr = _('Master color'),
-            usertext = _('Color'),
+            descr=_('Master color'),
+            usertext=_('Color'),
             formatting=True), 0 )
         s.add( setting.DistancePt(
             'markerSize',
             '3pt',
-            descr = _('Size of marker to plot'),
+            descr=_('Size of marker to plot'),
             usertext=_('Marker size'), formatting=True), 0 )
         s.add( setting.Marker(
             'marker',
             'circle',
-            descr = _('Type of marker to plot'),
+            descr=_('Type of marker to plot'),
             usertext=_('Marker'), formatting=True), 0 )
-        s.add( setting.DataColor('Color') )
 
         s.add( setting.ErrorStyle(
             'errorStyle',
@@ -382,44 +429,53 @@ class PointPlotter(GenericPlotter):
 
         s.add( setting.XYPlotLine(
             'PlotLine',
-            descr = _('Plot line settings'),
-            usertext = _('Plot line')),
-               pixmap = 'settings_plotline' )
+            descr=_('Plot line'),
+            usertext=_('Plot line')),
+            pixmap='settings_plotline' )
 
         s.add( setting.MarkerLine(
             'MarkerLine',
-            descr = _('Line around the marker settings'),
-            usertext = _('Marker border')),
-               pixmap = 'settings_plotmarkerline' )
+            descr=_('Line around marker'),
+            usertext=_('Marker border')),
+            pixmap='settings_plotmarkerline' )
         s.add( MarkerFillBrush(
             'MarkerFill',
-            descr = _('Marker fill settings'),
-            usertext = _('Marker fill')),
-               pixmap = 'settings_plotmarkerfill' )
+            descr=_('Marker fill'),
+            usertext=_('Marker fill')),
+            pixmap='settings_plotmarkerfill' )
 
         s.add( setting.ErrorBarLine(
             'ErrorBarLine',
-            descr = _('Error bar line settings'),
-            usertext = _('Error bar line')),
-               pixmap = 'settings_ploterrorline' )
+            descr=_('Error bar line'),
+            usertext=_('Error bar line')),
+            pixmap='settings_ploterrorline' )
         s.ErrorBarLine.get('color').newDefault( setting.Reference('../color') )
 
         s.add( setting.PointFill(
             'FillBelow',
-            descr = _('Fill mode 1'),
-            usertext = _('Fill 1')),
-               pixmap = 'settings_plotfillbelow' )
+            descr=_('Fill mode 1'),
+            usertext=_('Fill 1')),
+            pixmap='settings_plotfillbelow' )
         s.FillBelow.get('fillto').newDefault('bottom')
         s.add( setting.PointFill(
             'FillAbove',
-            descr = _('Fill mode 2'),
-            usertext = _('Fill 2')),
-               pixmap = 'settings_plotfillabove' )
+            descr=_('Fill 2'),
+            usertext=_('Fill 2')),
+            pixmap='settings_plotfillabove' )
         s.add( setting.PointLabel(
             'Label',
-            descr = _('Label settings'),
+            descr=_('Label settings'),
             usertext=_('Label')),
-               pixmap = 'settings_axislabel' )
+            pixmap='settings_axislabel' )
+
+    @classmethod
+    def addSettingsCompatLevel(klass, s, level):
+        if level >= 1:
+            s.FillBelow.get('color').newDefault(
+                setting.Reference('../color') )
+            s.FillAbove.get('color').newDefault(
+                setting.Reference('../color') )
+            s.MarkerFill.get('newMarkerSizes').newDefault(True)
 
     @property
     def userdescription(self):
@@ -472,14 +528,10 @@ class PointPlotter(GenericPlotter):
         if thin>1:
             xplotter, yplotter = xplotter[::thin], yplotter[::thin]
 
-        # iterate to call the error bars functions required to draw style
-        pen = s.ErrorBarLine.makeQPenWHide(painter)
-        pen.setCapStyle(qt.Qt.FlatCap)
-
-        painter.setPen(pen)
-        for function in _errorBarFunctionMap[style]:
-            function(style, xmin, xmax, ymin, ymax,
-                     xplotter, yplotter, s, painter, cliprect)
+        markersize = s.get('markerSize').convert(painter)
+        ebp = ErrorBarDraw(
+            s.errorStyle, s.ErrorBarLine, s.FillAbove, s.FillBelow, markersize)
+        ebp.plot(painter, xmin, xmax, ymin, ymax, xplotter, yplotter, cliprect)
 
     def affectsAxisRange(self):
         """This widget provides range information about these axes."""
@@ -492,22 +544,8 @@ class PointPlotter(GenericPlotter):
         dsetn = self.settings.get(dataname)
         data = dsetn.getData(self.document)
 
-        if axis.settings.log:
-            def updateRange(v):
-                with N.errstate(invalid='ignore'):
-                    chopzero = v[(v>0) & N.isfinite(v)]
-                if len(chopzero) > 0:
-                    axrange[0] = min(axrange[0], chopzero.min())
-                    axrange[1] = max(axrange[1], chopzero.max())
-        else:
-            def updateRange(v):
-                fvals = v[N.isfinite(v)]
-                if len(fvals) > 0:
-                    axrange[0] = min(axrange[0], fvals.min())
-                    axrange[1] = max(axrange[1], fvals.max())
-
         if data:
-            data.rangeVisit(updateRange)
+            data.updateRangeAuto(axrange, axis.settings.log)
         elif dsetn.isEmpty():
             # no valid dataset.
             # check if there a valid dataset for the other axis.
@@ -605,11 +643,11 @@ class PointPlotter(GenericPlotter):
                     pts.append( qt.QPointF(xvals[-1], yvals[-1]) )
 
         else:
-            assert False
+            raise RuntimeError('Invalid line mode')
 
         return pts
 
-    def _getBezierLine(self, poly, cliprect):
+    def _getBezierLine(self, poly, cliprect, beziertype):
         """Try to draw a bezier line connecting the points."""
 
         # clip to a larger box to help the lines get right angle
@@ -625,18 +663,22 @@ class PointPlotter(GenericPlotter):
         path = qt.QPainterPath()
         for lpoly in polys:
             if len(lpoly) >= 2:
-                npts = qtloops.bezier_fit_cubic_multi(lpoly, 0.1, len(lpoly)+1)
-                qtloops.addCubicsToPainterPath(path, npts);
+                if beziertype == "tight-Bezier":
+                    npts = qtloops.bezier_fit_cubic_tight(lpoly, 0.5)
+                else:
+                    npts = qtloops.bezier_fit_cubic_multi(
+                        lpoly, 0.1, len(lpoly)+1)
+                qtloops.addCubicsToPainterPath(path, npts)
         return path
 
     def _drawBezierLine( self, painter, xvals, yvals, posn,
-                         xdata, ydata, cliprect ):
+                         xdata, ydata, cliprect, beziertype ):
         """Handle bezier lines and fills."""
 
         pts = self._getLinePoints(xvals, yvals, posn, xdata, ydata)
         if len(pts) < 2:
             return
-        path = self._getBezierLine(pts, cliprect)
+        path = self._getBezierLine(pts, cliprect, beziertype)
         s = self.settings
 
         # do filling
@@ -731,10 +773,10 @@ class PointPlotter(GenericPlotter):
             yneg = ypos = ypts
 
         # plot error bar
-        painter.setPen( s.ErrorBarLine.makeQPenWHide(painter) )
-        for function in _errorBarFunctionMap[errstyle]:
-            function(errstyle, xneg, xpos, yneg, ypos, xpts, ypts, s,
-                     painter, cliprect)
+        markersize = s.get('markerSize').convert(painter)
+        ebp = ErrorBarDraw(
+            errstyle, s.ErrorBarLine, s.FillAbove, s.FillBelow, markersize)
+        ebp.plot(painter, xneg, xpos, yneg, ypos, xpts, ypts, cliprect)
 
         # draw line
         if not s.PlotLine.hide:
@@ -751,8 +793,7 @@ class PointPlotter(GenericPlotter):
             else:
                 painter.setPen( qt.QPen( qt.Qt.NoPen ) )
 
-            size = s.get('markerSize').convert(painter)
-            utils.plotMarker(painter, x+width/2, yp, s.marker, size)
+            utils.plotMarker(painter, x+width/2, yp, s.marker, markersize)
 
         painter.restore()
 
@@ -776,8 +817,7 @@ class PointPlotter(GenericPlotter):
         angle = lab.angle
 
         # iterate over each point and plot each label
-        for x, y, t in czip(xplotter+deltax, yplotter+deltay,
-                            textvals):
+        for x, y, t in zip(xplotter+deltax, yplotter+deltay, textvals):
             utils.Renderer(
                 painter, font, x, y, t,
                 alignhorz, alignvert, angle,
@@ -829,8 +869,10 @@ class PointPlotter(GenericPlotter):
         """Return parameters for colorbar."""
         s = self.settings
         c = s.Color
-        return (c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
-                s.MarkerFill.colorMapInvert)
+        return (
+            c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
+            s.MarkerFill.colorMapInvert
+        )
 
     def dataDraw(self, painter, axes, posn, cliprect):
         """Plot the data on a plotter."""
@@ -865,9 +907,12 @@ class PointPlotter(GenericPlotter):
             text = text*(length // len(text)) + text[:length % len(text)]
 
         # loop over chopped up values
+        nanbreak = s.nanHandling == 'break-on'
+
         for xvals, yvals, tvals, ptvals, cvals in (
             datasets.generateValidDatasetParts(
-                [xv, yv, text, scalepoints, colorpoints])):
+                [xv, yv, text, scalepoints, colorpoints],
+                breakds=nanbreak)):
 
             #print "Calculating coordinates"
             # calc plotter coords of x and y points
@@ -895,10 +940,11 @@ class PointPlotter(GenericPlotter):
             #print "Painting plot line"
             # plot data line (and/or filling above or below)
             if not s.PlotLine.hide or not s.FillAbove.hide or not s.FillBelow.hide:
-                if s.PlotLine.bezierJoin and hasqtloops:
+                interpolation_type = s.PlotLine.interpType
+                if interpolation_type != "linear":
                     self._drawBezierLine(
                         painter, xplotter, yplotter, posn,
-                        xvals, yvals, cliprect )
+                        xvals, yvals, cliprect, interpolation_type )
                 else:
                     self._drawPlotLine(
                         painter, xplotter, yplotter, posn,
@@ -908,8 +954,9 @@ class PointPlotter(GenericPlotter):
             # plot normal errors bars
             if s.errorStyle not in ('fillvert', 'fillhorz'):
                 # normally the error bar is painted after the line
-                self._plotErrors(posn, painter, xpltpoint, ypltpoint,
-                                 axes, xvals, yvals, cliprect)
+                self._plotErrors(
+                    posn, painter, xpltpoint, ypltpoint,
+                    axes, xvals, yvals, cliprect)
 
             # plot the points (we do this last so they are on top)
             markersize = s.get('markerSize').convert(painter)
@@ -962,7 +1009,9 @@ class PointPlotter(GenericPlotter):
                     painter, xplt, yplt, s.marker, markersize,
                     scaling=scaling, clip=cliprect,
                     cmap=cmap, colorvals=colorvals,
-                    scaleline=s.MarkerLine.scaleLine)
+                    scaleline=s.MarkerLine.scaleLine,
+                    equalarea=s.MarkerFill.newMarkerSizes,
+                )
 
             # finally plot any labels
             if tvals and not s.Label.hide:
@@ -971,4 +1020,4 @@ class PointPlotter(GenericPlotter):
                     tvals, markersize)
 
 # allow the factory to instantiate an x,y plotter
-document.thefactory.register( PointPlotter )
+document.thefactory.register(PointPlotter)
