@@ -16,24 +16,18 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function
 import os
 import os.path
 
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import utils
 from .. import document
-from ..compat import citems, cstrerror, cstr
 from .veuszdialog import VeuszDialog
 
 def _(text, disambiguation=None, context='ExportDialog'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
-
-# used in filename to mark page number
-PAGENUM = '%PAGENUM%'
-PAGENAME = '%PAGENAME%'
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # formats which can have multiple pages
 multipageformats = set(('ps', 'pdf'))
@@ -62,11 +56,11 @@ class ExportDialog(VeuszDialog):
         VeuszDialog.__init__(self, mainwindow, 'export.ui')
 
         self.document = doc
-        doc.signalModified.connect(self.updatePageMinMax)
-        self.updatePageMinMax()
+        doc.signalModified.connect(self.updatePagePages)
+        self.updatePagePages()
 
         # change 'Save' button to 'Export'
-        self.buttonBox.button(qt4.QDialogButtonBox.Save).setText(_('Export'))
+        self.buttonBox.button(qt.QDialogButtonBox.Save).setText(_('Export'))
 
         # these are mappings between filetypes and radio buttons
         self.fmtradios = dict([(f, getattr(self, r)) for f, r in formatradio])
@@ -74,26 +68,26 @@ class ExportDialog(VeuszDialog):
 
         # get allowed types (some formats are disabled if no helper)
         docfmts = set()
-        for types, descr in document.Export.formats:
+        for types, descr in document.AsyncExport.getFormats():
             docfmts.update(types)
         # disable type if not allowed
-        for fmt, radio in citems(self.fmtradios):
+        for fmt, radio in self.fmtradios.items():
             if fmt not in docfmts:
                 radio.setEnabled(False)
 
         # connect format radio buttons
         def fmtclicked(f):
             return lambda: self.formatClicked(f)
-        for r, f in citems(self.radiofmts):
+        for r, f in self.radiofmts.items():
             r.clicked.connect(fmtclicked(f))
 
         # connect page radio buttons
         self.radioPageSingle.clicked.connect(lambda: self.pageClicked('single'))
         self.radioPageAll.clicked.connect(lambda: self.pageClicked('all'))
-        self.radioPageRange.clicked.connect(lambda: self.pageClicked('range'))
+        self.radioPagePages.clicked.connect(lambda: self.pageClicked('pages'))
 
         # other controls
-        self.checkMultiPage.clicked.connect(self.updateFilename)
+        self.checkMultiPage.clicked.connect(self.updateSingleMulti)
         self.buttonBrowse.clicked.connect(self.browseClicked)
 
         setdb = setting.settingdb
@@ -106,33 +100,32 @@ class ExportDialog(VeuszDialog):
         elif eloc == 'cwd':
             self.dirname = os.getcwd()
         else: # 'prev'
-            self.dirname = setdb.get('dirname_export', qt4.QDir.homePath())
+            self.dirname = setdb.get('dirname_export', qt.QDir.homePath())
 
         # set default filename
         ext = setdb.get('export_format', 'pdf')
         if not docfilename:
             docfilename = 'export'
-        filename = os.path.join(
-            self.dirname,
-            os.path.splitext(os.path.basename(docfilename))[0] + '.' + ext)
-        self.editFileName.setText(filename)
+        self.docname = os.path.splitext(os.path.basename(docfilename))[0]
 
         self.formatselected = ext
         self.pageselected = setdb.get('export_page', 'single')
 
-        self.checkOverwrite.setChecked(setdb.get('export_overwrite', False))
         self.checkMultiPage.setChecked(setdb.get('export_multipage', True))
+        self.updateSingleMulti()
+
+        self.checkOverwrite.setChecked(setdb.get('export_overwrite', False))
         self.exportSVGTextAsText.setChecked(setdb['export_SVG_text_as_text'])
         self.exportAntialias.setChecked(setdb['export_antialias'])
         self.exportQuality.setValue(setdb['export_quality'])
 
         # validate and set DPIs
-        dpis = ('75', '90', '100', '150', '200', '300')
-        self.exportDPI.addItems(dpis)
-        self.exportDPIPDF.addItems(dpis)
-        self.exportDPI.setValidator(qt4.QIntValidator(10, 10000, self))
+        dpis = ('72', '75', '90', '96', '100', '150', '200', '300')
+        for cntrl in self.exportDPI, self.exportDPISVG, self.exportDPIPDF:
+            cntrl.addItems(dpis)
+            cntrl.setValidator(qt.QIntValidator(10, 10000, self))
         self.exportDPI.setEditText(str(setdb['export_DPI']))
-        self.exportDPIPDF.setValidator(qt4.QIntValidator(10, 10000, self))
+        self.exportDPISVG.setEditText(str(setdb['export_DPI_SVG']))
         self.exportDPIPDF.setEditText(str(setdb['export_DPI_PDF']))
 
         # button to change bitmap background
@@ -143,11 +136,18 @@ class ExportDialog(VeuszDialog):
         # set correct format
         self.fmtradios[ext].click()
 
+        # regexp for comma separated ranges
+        valre = qt.QRegExp(
+            r'^[0-9]+(\s*-\s*[0-9]+)?(\s*,\s*[0-9]+(\s*-\s*[0-9]+)?)*$')
+        valid = qt.QRegExpValidator(valre, self)
+        self.editPagePages.setValidator(valid)
+
         # set page mode
         {
+            'range': self.radioPageSingle, # compatibility
             'single': self.radioPageSingle,
             'all': self.radioPageAll,
-            'range': self.radioPageRange,
+            'pages': self.radioPagePages,
         }[self.pageselected].click()
 
         # label showing success/failure
@@ -163,7 +163,6 @@ class ExportDialog(VeuszDialog):
         setting.settingdb['export_format'] = fmt
         self.formatselected = fmt
         self.checkMultiPage.setEnabled(fmt in multipageformats)
-        self.updateFilename()
 
         for c in (self.exportAntialias, self.exportDPI, self.labelDPI,
                   self.exportBackgroundButton, self.labelBackgroundButton):
@@ -176,17 +175,21 @@ class ExportDialog(VeuszDialog):
         for c in (self.exportQuality, self.labelQuality):
             c.setVisible(fmt == 'jpg')
 
-        for c in (self.exportSVGTextAsText, self.labelSVGTextAsText):
+        for c in (self.exportSVGTextAsText, self.labelSVGTextAsText,
+                  self.exportDPISVG, self.labelDPISVG):
             c.setVisible(fmt == 'svg')
 
+        self.updateSingleMulti()
+        filename = os.path.splitext(self.editFileName.text())[0] + '.' + fmt
+        self.editFileName.setText(filename)
+
     def pageClicked(self, page):
         """If page type is set."""
         setting.settingdb['export_page'] = page
         self.pageselected = page
-        self.updateFilename()
+        self.updateSingleMulti()
 
-        self.pageRangeMin.setEnabled(page=='range')
-        self.pageRangeMax.setEnabled(page=='range')
+        self.editPagePages.setEnabled(page=='pages')
 
     def browseClicked(self):
         """Browse for file."""
@@ -194,15 +197,15 @@ class ExportDialog(VeuszDialog):
         setdb = setting.settingdb
 
         # File types we can export to in the form ([extensions], Name)
-        fd = qt4.QFileDialog(self, _('Export page'))
+        fd = qt.QFileDialog(self, _('Export page'))
 
         filename = self.editFileName.text()
         dirname = os.path.dirname(self.editFileName.text())
         fd.setDirectory(dirname if dirname else self.dirname)
 
-        fd.setFileMode(qt4.QFileDialog.AnyFile)
-        fd.setAcceptMode(qt4.QFileDialog.AcceptSave)
-        fd.setOptions(qt4.QFileDialog.DontConfirmOverwrite)
+        fd.setFileMode(qt.QFileDialog.AnyFile)
+        fd.setAcceptMode(qt.QFileDialog.AcceptSave)
+        fd.setOptions(qt.QFileDialog.DontConfirmOverwrite)
 
         # Create a mapping between a format string and extensions
         filtertoext = {}
@@ -211,7 +214,7 @@ class ExportDialog(VeuszDialog):
         filters = []
         # a list of extensions which are allowed
         validextns = []
-        formats = document.Export.formats
+        formats = document.AsyncExport.getFormats()
         for extns, name in formats:
             extensions = " ".join(["*." + item for item in extns])
             # join eveything together to make a filter string
@@ -230,9 +233,9 @@ class ExportDialog(VeuszDialog):
         if os.path.isdir(dirname):
             fd.selectFile(filename)
 
-        if fd.exec_() == qt4.QDialog.Accepted:
+        if fd.exec_() == qt.QDialog.Accepted:
             # convert filter to extension
-            filterused = str(fd.selectedFilter())
+            filterused = str(fd.selectedNameFilter())
             chosenext = filtertoext[filterused][0]
 
             filename = fd.selectedFiles()[0]
@@ -244,43 +247,40 @@ class ExportDialog(VeuszDialog):
 
     def isMultiFile(self):
         """Is output going to be multiple pages?"""
-        multipage = self.pageselected != 'single'
+        multifile = self.pageselected != 'single'
         if (self.formatselected in multipageformats and
             self.checkMultiPage.isChecked()):
-            multipage = False
-        return multipage
+            multifile = False
+        return multifile
 
-    def updateFilename(self):
-        """Change filename according to selected radio buttons."""
-        filename = self.editFileName.text()
+    def updateSingleMulti(self, _oldmulti=[None]):
+        """Change filename according to selected single or multi button."""
         setting.settingdb['export_multipage'] = self.checkMultiPage.isChecked()
-        if filename:
-            dotpos = filename.rfind('.')
-            left = filename if dotpos==-1 else filename[:dotpos]
-            multifile = self.isMultiFile()
+        multifile = self.isMultiFile()
+        if multifile:
+            templ = setting.settingdb['export_template_multi']
+        else:
+            templ = setting.settingdb['export_template_single']
 
-            if multifile and (PAGENUM not in left and PAGENAME not in left):
-                left += PAGENUM
-            elif not multifile:
-                left = left.replace(PAGENUM, '')
-                left = left.replace(PAGENAME, '')
+        newfilename = os.path.join(
+            self.dirname,
+            templ.replace('%DOCNAME%', self.docname) + '.' + self.formatselected)
 
-            newfilename = left + '.' + self.formatselected
+        # only change if multi format status has changed or is
+        # uninitialised
+        if multifile is not getattr(self, '_oldsinglemulti', None):
             self.editFileName.setText(newfilename)
+            self._oldsinglemulti = multifile
 
-    def updatePageMinMax(self):
-        """Update widgets allowing user to set page range."""
+    def updatePagePages(self):
+        """Update widgets allowing user to set ranges of pages."""
         npages = self.document.getNumberPages()
         if npages == 0:
             return
-        if self.pageRangeMax.value() == 0:
-            self.pageRangeMax.setValue(npages)
-        self.pageRangeMin.setMinimum(1)
-        self.pageRangeMin.setMaximum(npages)
-        self.pageRangeMax.setMinimum(1)
-        self.pageRangeMax.setMaximum(npages)
+        text = '%i-%i' % (1, npages)
+        self.editPagePages.setText(text)
 
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def clearLabel(self):
         """Clear label.
         Defined as a slot to work around PyQt C++ object deleted bug. """
@@ -289,53 +289,89 @@ class ExportDialog(VeuszDialog):
     def showMessage(self, text):
         """Show a message in a label, clearing after a time."""
         self.labelStatus.setText(text)
-        qt4.QTimer.singleShot(3000, self.clearLabel)
+        qt.QTimer.singleShot(3000, self.clearLabel)
 
     def updateExportBackground(self, colorname):
         """Update color on export background."""
-        pixmap = qt4.QPixmap(16, 16)
-        col = utils.extendedColorToQColor(colorname)
+        pixmap = qt.QPixmap(16, 16)
+        col = self.document.evaluate.colors.get(colorname)
         pixmap.fill(col)
 
         # update button (storing color in button itself - what fun!)
-        self.exportBackgroundButton.setIcon(qt4.QIcon(pixmap))
+        self.exportBackgroundButton.setIcon(qt.QIcon(pixmap))
         self.exportBackgroundButton.iconcolor = colorname
 
     def slotExportBackgroundClicked(self):
         """Button clicked to change background."""
-        color = qt4.QColorDialog.getColor(
-            utils.extendedColorToQColor(self.exportBackgroundButton.iconcolor),
+        qcolor = self.document.evaluate.colors.get(
+            self.exportBackgroundButton.iconcolor)
+        color = qt.QColorDialog.getColor(
+            qcolor,
             self,
             "Choose color",
-            qt4.QColorDialog.ShowAlphaChannel )
+            qt.QColorDialog.ShowAlphaChannel )
         if color.isValid():
             self.updateExportBackground(utils.extendedColorFromQColor(color))
 
+    def getPagePages(self):
+        """Get list of entered pages."""
+        visible = set(self.document.getVisiblePages())
+
+        txt = self.editPagePages.text()
+        parts = txt.split(',')
+        pages = []
+        for p in parts:
+            p = p.replace(' ', '')
+            try:
+                if p.find('-')>=0:
+                    rng = p.split('-')
+                    for pg in range(int(rng[0])-1, int(rng[1])):
+                        if pg in visible:
+                            pages.append(pg)
+                else:
+                    pg = int(p)-1
+                    if pg in visible:
+                        pages.append(pg)
+            except ValueError:
+                # convertsion error
+                raise RuntimeError(_('Error: invalid list of pages'))
+        # check in range
+        for pg in pages:
+            if pg<0 or pg>=self.document.getNumberPages():
+                raise RuntimeError(_('Error: pages out of range'))
+        return pages
+
     def accept(self):
         """Do the export"""
 
-        if self.document.getNumberPages() == 0:
-            self.showMessage(_('Error: no pages in document'))
+        if not self.document.getVisiblePages():
+            self.showMessage(_('Error: no visible pages in document'))
             return
 
         filename = self.editFileName.text()
-        if (self.isMultiFile() and PAGENUM not in filename and
-            PAGENAME not in filename):
-            self.showMessage(_('Error: %s or %s not in filename') % (
-                PAGENUM, PAGENAME))
-            return
-        if self.pageselected == 'range' and (
-                self.pageRangeMin.value() > self.pageRangeMax.value()):
-            self.showMessage(_('Error: page range invalid'))
+        if (self.isMultiFile() and
+            '%PAGENAME%' not in filename and
+            '%PAGE%' not in filename and
+            '%PAGE00%' not in filename and
+            '%PAGE000%' not in filename):
+            self.showMessage(
+                _('Error: page name or number must be in filename'))
             return
 
+        # add extension to filename if missing
+        if not os.path.splitext(filename)[1]:
+            filename += '.' + self.formatselected
+
         if self.pageselected == 'single':
             pages = [self.mainwindow.plot.getPageNumber()]
         elif self.pageselected == 'all':
-            pages = list(range(self.document.getNumberPages()))
-        elif self.pageselected == 'range':
-            pages = list(range(
-                self.pageRangeMin.value()-1, self.pageRangeMax.value()))
+            pages = self.document.getVisiblePages()
+        elif self.pageselected == 'pages':
+            try:
+                pages = self.getPagePages()
+            except RuntimeError as e:
+                self.showMessage(str(e))
+                return
 
         setdb = setting.settingdb
 
@@ -349,20 +385,20 @@ class ExportDialog(VeuszDialog):
 
         # update dpi if possible
         # FIXME: requires some sort of visual notification of validator
-        for cntrl, setn in ((self.exportDPI, 'export_DPI'),
-                            (self.exportDPIPDF, 'export_DPI_PDF')):
+        for cntrl, setn in (
+                (self.exportDPI, 'export_DPI'),
+                (self.exportDPIPDF, 'export_DPI_PDF'),
+                (self.exportDPISVG, 'export_DPI_SVG')):
             try:
                 text = cntrl.currentText()
                 valid = cntrl.validator().validate(text, 0)[0]
-                if valid == qt4.QValidator.Acceptable:
+                if valid == qt.QValidator.Acceptable:
                     setdb[setn] = int(text)
             except ValueError:
                 pass
 
-        export = document.Export(
+        export = document.AsyncExport(
             self.document,
-            '',  # filename
-            0,   # page number
             bitmapdpi=setdb['export_DPI'],
             pdfdpi=setdb['export_DPI_PDF'],
             antialias=setdb['export_antialias'],
@@ -370,75 +406,96 @@ class ExportDialog(VeuszDialog):
             quality=setdb['export_quality'],
             backcolor=setdb['export_background'],
             svgtextastext=setdb['export_SVG_text_as_text'],
+            svgdpi=setdb['export_DPI_SVG'],
         )
 
         def _overwriteQuestion(filename):
             """Ask user whether file can be overwritten."""
-            msgbox = qt4.QMessageBox(
-                qt4.QMessageBox.Question,
+            retn = qt.QMessageBox.question(
+                self,
                 _("Overwrite file?"),
                 _("The file %s already exists") % os.path.basename(filename),
-                qt4.QMessageBox.Save | qt4.QMessageBox.Ignore,
-                self)
-            msgbox.setDefaultButton(qt4.QMessageBox.Ignore)
-            msgbox.button(qt4.QMessageBox.Save).setText(_('Overwrite'))
-            msgbox.button(qt4.QMessageBox.Ignore).setText(_('Keep'))
-            return msgbox.exec_() == qt4.QMessageBox.Save
+                qt.QMessageBox.Save | qt.QMessageBox.Cancel,
+                qt.QMessageBox.Cancel)
+            return retn == qt.QMessageBox.Save
 
         # count exported pages (in list so can be modified in function)
         pagecount = [0]
-        def _checkAndExport():
+        def _checkAndExport(fname, pages):
             """Check whether file exists and export if ok."""
-            if os.path.exists(export.filename):
+            if os.path.exists(fname):
                 if not setdb['export_overwrite']:
-                    if not _overwriteQuestion(export.filename):
+                    if not _overwriteQuestion(fname):
                         return
 
-            # show busy cursor
-            qt4.QApplication.setOverrideCursor(qt4.QCursor(qt4.Qt.WaitCursor))
             # delete file if already exists
             try:
-                os.unlink(export.filename)
+                os.unlink(fname)
             except EnvironmentError:
                 pass
 
-            try:
-                # actually do the export
-                export.export()
-                pagecount[0] += len(export.pagenumber)
-            except (RuntimeError, EnvironmentError) as e:
-                # errors from the export
-                if isinstance(e, EnvironmentError):
-                    msg = cstrerror(e)
-                else:
-                    msg = cstr(e)
-                qt4.QApplication.restoreOverrideCursor()
-                qt4.QMessageBox.critical(
-                    self, _("Error - Veusz"),
-                    _("Error exporting to file '%s'\n\n%s") %
-                    (export.filename, msg))
-            else:
-                qt4.QApplication.restoreOverrideCursor()
+            # actually do the export
+            export.add(fname, pages)
+            pagecount[0] += len(pages)
 
-        if self.isMultiFile():
+            ext = os.path.splitext(fname)[1]
+            if ext:
+                utils.feedback.exportcts[ext] += 1
+
+        if self.isMultiFile() or len(pages)==1:
             # write pages to multiple files
             for page in pages:
                 pagename = self.document.getPage(page).name
-                export.pagenumber = [page]
-                export.filename = os.path.join(
-                    os.path.dirname(filename),
-                    os.path.basename(filename).replace(PAGENUM, str(page+1)).
-                    replace(PAGENAME, pagename)
-                )
-                _checkAndExport()
+
+                pg = page+1
+                fname = filename.replace('%PAGE%', str(pg))
+                fname = fname.replace('%PAGE00%', '%02i' % pg)
+                fname = fname.replace('%PAGE000%', '%03i' % pg)
+                fname = fname.replace('%PAGENAME%', pagename)
+                _checkAndExport(fname, [page])
         else:
             # write page/pages to single file
-            export.pagenumber = pages
-            export.filename = filename
-            _checkAndExport()
+            fname = filename.replace('%PAGE%', _('none'))
+            fname = fname.replace('%PAGE00%', _('none'))
+            fname = fname.replace('%PAGE000%', _('none'))
+            fname = fname.replace('%PAGENAME%', _('none'))
+
+            _checkAndExport(fname, pages)
 
         dirname = os.path.dirname(filename)
         if dirname:
             setting.settingdb['dirname_export'] = dirname
 
-        self.showMessage(_('Exported %i page(s)') % pagecount[0])
+        # format feedback
+        self.showMessage(_('Processing...'))
+
+        self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(False)
+        self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(False)
+
+        def checkDone():
+            """Check whether exporting has finished."""
+            if not export.haveDone():
+                return
+            try:
+                export.finish()
+            except (RuntimeError, EnvironmentError) as e:
+                # errors from the export
+                if isinstance(e, EnvironmentError):
+                    msg = e.strerror
+                else:
+                    msg = str(e)
+                qt.QMessageBox.critical(
+                    self, _("Error - Veusz"),
+                    _("Error exporting to file '%s'\n\n%s") %
+                    (fname, msg))
+            else:
+                if pagecount[0] > 0:
+                    self.showMessage(_('Exported %i page(s)') % pagecount[0])
+
+            self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(True)
+            self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(True)
+            self.checktimer.stop()
+
+        self.checktimer = qt.QTimer(self)
+        self.checktimer.timeout.connect(checkDone)
+        self.checktimer.start(20)
