@@ -16,7 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 from .. import qtall as qt
 from .. import setting
 from .. import utils
@@ -29,17 +28,17 @@ def _(text, disambiguation=None, context="PrefsDialog"):
 
 # names for display of colors and a longer description
 color_names = {
-    'page': (_('Page'),
-             _('Page background color')),
-    'error': (_('Error'),
-              _('Color for errors')),
-    'command': (_('Console command'),
-                _('Commands in the console window color')),
-    'cntrlline': (_('Control line'),
-                  _('Color of lines controlling widgets')),
-    'cntrlcorner': (_('Control corner'),
-                    _('Color of corners controlling widgets')),
-    }
+    'page': (
+        _('Page'), _('Page background color')),
+    'error': (
+        _('Error'), _('Color for errors')),
+    'command': (
+        _('Console command'), _('Commands in the console window color')),
+    'cntrlline': (
+        _('Control line'), _('Color of lines controlling widgets')),
+    'cntrlcorner': (
+        _('Control corner'), _('Color of corners controlling widgets')),
+}
 
 class PreferencesDialog(VeuszDialog):
     """Preferences dialog."""
@@ -69,12 +68,15 @@ class PreferencesDialog(VeuszDialog):
         # disable thread option if not supported
         if not qt.QFontDatabase.supportsThreadedFontRendering():
             self.threadSpinBox.setEnabled(False)
-            self.threadSpinBox.setToolTip(_("Disabled because of lack of "
-                                            "threaded drawing support"))
+            self.threadSpinBox.setToolTip(
+                _("Disabled because of lack of threaded drawing support"))
 
         # use cwd for file dialogs
         (self.dirDocCWDRadio if setdb['dirname_usecwd'] else self.dirDocPrevRadio).click()
 
+        # add import paths
+        self.docFileAddImportPaths.setChecked( setdb['docfile_addimportpaths'] )
+
         # exporting documents
         {
             'doc': self.dirExportDocRadio,
@@ -112,6 +114,7 @@ class PreferencesDialog(VeuszDialog):
         # for point picker
         self.pickerToConsoleCheck.setChecked( setdb['picker_to_console'] )
         self.pickerToClipboardCheck.setChecked( setdb['picker_to_clipboard'] )
+        self.pickerSigFigs.setValue( setdb['picker_sig_figs'] )
 
         # python path
         self.externalPythonPath.setText(setdb['external_pythonpath'])
@@ -125,6 +128,13 @@ class PreferencesDialog(VeuszDialog):
         if utils.disableFeedback:
             self.externalFeedbackCheck.setEnabled(False)
 
+        # security
+        self.securityDirList.addItems(setdb['secure_dirs'])
+        self.securityDirList.itemSelectionChanged.connect(
+            self.securityDirListSelection)
+        self.securityDirAdd.clicked.connect(self.securityDirAddClicked)
+        self.securityDirRemove.clicked.connect(self.securityDirRemoveClicked)
+
     def setupColorTab(self):
         """Initialise color tab
         this makes a grid of controls for each color
@@ -203,12 +213,16 @@ class PreferencesDialog(VeuszDialog):
 
         # use cwd
         setdb['dirname_usecwd'] = self.dirDocCWDRadio.isChecked()
+        setdb['docfile_addimportpaths'] = self.docFileAddImportPaths.isChecked()
+
+        # add import paths
+        setdb['docfile_addimportpaths'] = self.docFileAddImportPaths.isChecked()
 
         for radio, val in (
                 (self.dirExportDocRadio, 'doc'),
                 (self.dirExportCWDRadio, 'cwd'),
                 (self.dirExportPrevRadio, 'prev'),
-                ):
+        ):
             if radio.isChecked():
                 setdb['dirname_export_location'] = val
 
@@ -244,6 +258,7 @@ class PreferencesDialog(VeuszDialog):
         # picker
         setdb['picker_to_clipboard'] = self.pickerToClipboardCheck.isChecked()
         setdb['picker_to_console'] = self.pickerToConsoleCheck.isChecked()
+        setdb['picker_sig_figs'] = self.pickerSigFigs.value()
 
         # python path
         setdb['external_pythonpath'] = self.externalPythonPath.text()
@@ -254,6 +269,12 @@ class PreferencesDialog(VeuszDialog):
         # feedback
         setdb['feedback_disabled'] = self.externalFeedbackCheck.isChecked()
 
+        # security
+        setdb['secure_dirs'] = [
+            self.securityDirList.item(i).text()
+            for i in range(self.securityDirList.count())
+        ]
+
         self.plotwindow.updatePlotSettings()
 
         # write settings out now, rather than wait until the end
@@ -286,8 +307,8 @@ class PreferencesDialog(VeuszDialog):
             [_('Python scripts (*.py)')], _('Choose plugin'))
         if filename:
             self.pluginmodel.insertRows(0, 1)
-            self.pluginmodel.setData( self.pluginmodel.index(0),
-                                      filename )
+            self.pluginmodel.setData(
+                self.pluginmodel.index(0), filename)
 
     def pluginRemoveClicked(self):
         """Remove selected plugin."""
@@ -302,3 +323,22 @@ class PreferencesDialog(VeuszDialog):
             [_('All files (*)')], _('Choose ghostscript executable'))
         if filename:
             self.externalGhostscript.setText(filename)
+
+    def securityDirListSelection(self):
+        """Hide or show remove button."""
+        self.securityDirRemove.setEnabled(
+            len(self.securityDirList.selectedItems())>0)
+
+    def securityDirAddClicked(self):
+        """Add a secure directory."""
+
+        dirname = qt.QFileDialog.getExistingDirectory(
+            self, _('Choose secure directory to add'))
+        if dirname:
+            self.securityDirList.addItem(dirname)
+
+    def securityDirRemoveClicked(self):
+        """Remove a secure directory."""
+
+        for item in self.securityDirList.selectedItems():
+            self.securityDirList.takeItem(self.securityDirList.row(item))
