@@ -18,12 +18,11 @@
 
 """Data entry fields for plugins."""
 
-from __future__ import division
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import utils
 from .. import setting
 
-class Field(object):
+class Field:
     """A class to represent an input field on the dialog or command line."""
     def __init__(self, name, descr=None, default=None):
         """name: name of field
@@ -52,8 +51,8 @@ class FieldText(Field):
     """Text entry on the dialog."""
 
     def makeControl(self, doc, currentwidget):
-        l = qt4.QLabel(self.descr)
-        e = qt4.QLineEdit()
+        l = qt.QLabel(self.descr)
+        e = qt.QLineEdit()
         if self.default:
             e.setText(self.default)
         return (l, e)
@@ -64,6 +63,23 @@ class FieldText(Field):
     def getControlResults(self, cntrls):
         return cntrls[1].text()
 
+class FieldTextEdit(Field):
+    """Text entry on the dialog."""
+
+    def makeControl(self, doc, currentwidget):
+        l = qt.QLabel(self.descr)
+        e = qt.QTextEdit()
+        e.setTabStopWidth(20) #for tab positions
+        if self.default:
+            e.setText(self.default)
+        return (l, e)
+
+    def setControlVal(self, controls, val):
+        controls[1].setText(val)
+
+    def getControlResults(self, cntrls):
+        return cntrls[1].toPlainText()
+
 class FieldCombo(Field):
     """Drop-down combobox on dialog."""
     def __init__(self, name, descr=None, default=None, items=(),
@@ -78,8 +94,8 @@ class FieldCombo(Field):
         self.editable = editable
 
     def makeControl(self, doc, currentwidget):
-        l = qt4.QLabel(self.descr)
-        c = qt4.QComboBox()
+        l = qt.QLabel(self.descr)
+        c = qt.QComboBox()
         c.addItems(self.items)
         c.setEditable(bool(self.editable))
 
@@ -98,7 +114,7 @@ class FieldCombo(Field):
     def getControlResults(self, cntrls):
         return cntrls[1].currentText()
 
-class _WidgetCombo(qt4.QComboBox):
+class _WidgetCombo(qt.QComboBox):
     """Combo box for selecting widgets."""
 
     def __init__(self, doc, widgettypes, default):
@@ -106,7 +122,7 @@ class _WidgetCombo(qt4.QComboBox):
         widgettypes: set of allowed widgettypes or empty for all
         default: default path."""
 
-        qt4.QComboBox.__init__(self)
+        qt.QComboBox.__init__(self)
         self.doc = doc
         self.widgettypes = widgettypes
         self.default = default
@@ -126,7 +142,7 @@ class _WidgetCombo(qt4.QComboBox):
         for w in widget.children:
             self._iterateWidgets(comboitems, paths, w, level+1)
 
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def updateWidgets(self):
         """Update combo with new widgets."""
 
@@ -147,7 +163,7 @@ class _WidgetCombo(qt4.QComboBox):
 
         # set tool tip for each entry which is the path
         for i, path in enumerate(self.paths):
-            self.setItemData(i, path, qt4.Qt.ToolTipRole)
+            self.setItemData(i, path, qt.Qt.ToolTipRole)
 
     def getWidgetPath(self):
         """Get path of selected widget."""
@@ -169,7 +185,7 @@ class FieldWidget(Field):
         if default == '':
             default = currentwidget
 
-        l = qt4.QLabel(self.descr)
+        l = qt.QLabel(self.descr)
         c = _WidgetCombo(doc, self.widgettypes, default)
         return (l, c)
 
@@ -195,7 +211,7 @@ class _FieldSetting(Field):
         self.setn.set(self.default)
 
         self.document = doc
-        l = qt4.QLabel(self.descr)
+        l = qt.QLabel(self.descr)
         c = self.setn.makeControl(None)
 
         def updateval(cntrl, setn, val):
@@ -220,8 +236,8 @@ class _FieldSetting(Field):
 class FieldBool(_FieldSetting):
     """A true/false value using a check box."""
     def __init__(self, name, descr=None, default=False):
-        _FieldSetting.__init__(self, setting.Bool, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Bool, name, descr=descr, default=default)
 
 class FieldInt(_FieldSetting):
     """An integer number field."""
@@ -233,9 +249,11 @@ class FieldInt(_FieldSetting):
         default: default value.
         minval and maxval: minimum and maximum integers
         """
-        _FieldSetting.__init__(self, setting.Int,
-                               name, descr=descr, default=default,
-                               setnparams={'minval': minval, 'maxval': maxval})
+        _FieldSetting.__init__(
+            self, setting.Int,
+            name, descr=descr, default=default,
+            setnparams={'minval': minval, 'maxval': maxval}
+        )
 
 class FieldFloat(_FieldSetting):
     """A floating point number field."""
@@ -248,9 +266,11 @@ class FieldFloat(_FieldSetting):
         minval and maxval: minimum and maximum values
         """
 
-        _FieldSetting.__init__(self, setting.Float,
-                               name, descr=descr, default=default,
-                               setnparams={'minval': minval, 'maxval': maxval})
+        _FieldSetting.__init__(
+            self, setting.Float,
+            name, descr=descr, default=default,
+            setnparams={'minval': minval, 'maxval': maxval}
+        )
 
 class FieldFloatOrAuto(_FieldSetting):
     """A floating point value or the text 'Auto'."""
@@ -261,53 +281,53 @@ class FieldFloatOrAuto(_FieldSetting):
         default: default value.
         """
 
-        _FieldSetting.__init__(self, setting.FloatOrAuto,
-                               name, descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.FloatOrAuto, name, descr=descr, default=default)
 
 class FieldColor(_FieldSetting):
     """Field for selecting a color - returns #rrggbb string."""
     def __init__(self, name, descr=None, default='black'):
-        _FieldSetting.__init__(self, setting.Color, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Color, name, descr=descr, default=default)
 
 class FieldFillStyle(_FieldSetting):
     """Field for selecting fill styles - returns a string."""
     def __init__(self, name, descr=None, default='solid'):
-        _FieldSetting.__init__(self, setting.FillStyle, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.FillStyle, name, descr=descr, default=default)
 
 class FieldLineStyle(_FieldSetting):
     """Field for selecting line styles - returns a string."""
     def __init__(self, name, descr=None, default='solid'):
-        _FieldSetting.__init__(self, setting.LineStyle, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.LineStyle, name, descr=descr, default=default)
 
 class FieldMarker(_FieldSetting):
     """Field for selecting a marker type.
-    
+
     Returns a string
     """
     def __init__(self, name, descr=None, default='circle'):
-        _FieldSetting.__init__(self, setting.Marker, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Marker, name, descr=descr, default=default)
 
 class FieldArrow(_FieldSetting):
     """Field for selecting an arrow type.
-    
+
     Returns a string
     """
     def __init__(self, name, descr=None, default='none'):
-        _FieldSetting.__init__(self, setting.Arrow, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Arrow, name, descr=descr, default=default)
 
 class FieldErrorStyle(_FieldSetting):
     """Field for selecting an error bar style
-    
+
     Returns a string
     """
     def __init__(self, name, descr=None, default='bar'):
-        _FieldSetting.__init__(self, setting.ErrorStyle, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.ErrorStyle, name, descr=descr, default=default)
 
 class FieldDistance(_FieldSetting):
     """Field for selecting a veusz-style distance, e.g. '1pt'.
@@ -315,8 +335,8 @@ class FieldDistance(_FieldSetting):
     Returns a string
     """
     def __init__(self, name, descr=None, default='1pt'):
-        _FieldSetting.__init__(self, setting.Distance, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Distance, name, descr=descr, default=default)
 
 class FieldFloatList(_FieldSetting):
     """Field for entering multiple numbers, separated by commas or spaces
@@ -324,8 +344,8 @@ class FieldFloatList(_FieldSetting):
     Returns a list/tuple of floats
     """
     def __init__(self, name, descr=None, default=()):
-        _FieldSetting.__init__(self, setting.FloatList, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.FloatList, name, descr=descr, default=default)
 
 class FieldDataset(_FieldSetting):
     """Field for selecting a datset.
@@ -343,18 +363,19 @@ class FieldDataset(_FieldSetting):
         dims: dimensions of dataset to show (or 'all')
         datatype: type of data: numeric, text or all
         """
-        _FieldSetting.__init__(self, setting.Dataset,
-                               name, descr=descr, default=default,
-                               setnparams={'dimensions': dims,
-                                           'datatype': datatype})
+        _FieldSetting.__init__(
+            self, setting.Dataset,
+            name, descr=descr, default=default,
+            setnparams={'dimensions': dims, 'datatype': datatype}
+        )
 
 class FieldTextMulti(_FieldSetting):
     """Field for entering multiple lines of text.
     Returns a tuple/list of strings.
     """
     def __init__(self, name, descr=None, default=('')):
-        _FieldSetting.__init__(self, setting.Strings, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.Strings, name, descr=descr, default=default)
 
 class FieldDatasetMulti(_FieldSetting):
     """Field for entering multiple datasets.
@@ -367,10 +388,11 @@ class FieldDatasetMulti(_FieldSetting):
 
         datatype is 'numeric' or 'text'
         """
-        _FieldSetting.__init__(self, setting.Datasets, name,
-                               descr=descr, default=default,
-                               setnparams={'dimensions': dims,
-                                           'datatype': datatype})
+        _FieldSetting.__init__(
+            self, setting.Datasets, name,
+            descr=descr, default=default,
+            setnparams={'dimensions': dims, 'datatype': datatype}
+        )
 
 class FieldLineMulti(_FieldSetting):
     """A field for holding a set of lines. Consists of tuples
@@ -384,14 +406,14 @@ class FieldLineMulti(_FieldSetting):
 
     def __init__(self, name, descr=None,
                  default=(('solid', '1pt', 'black', False),) ):
-        _FieldSetting.__init__(self, setting.LineSet, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.LineSet, name, descr=descr, default=default)
 
 class FieldFillMulti(_FieldSetting):
     """A field for holding a set of fills. Consists of tuples
 
     [('solid', 'color', <trans>, False), ...]
-        
+
     These are color, fill style, and hide or
     color, fill style, transparency and hide
 
@@ -399,8 +421,8 @@ class FieldFillMulti(_FieldSetting):
     """
 
     def __init__(self, name, descr=None, default=()):
-        _FieldSetting.__init__(self, setting.FillSet, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.FillSet, name, descr=descr, default=default)
 
 class FieldFontFamily(_FieldSetting):
     """A field for holding a font family.
@@ -412,22 +434,19 @@ class FieldFontFamily(_FieldSetting):
         """Default None selects the default font."""
         if default is None:
             default = setting.Text.defaultfamily
-        _FieldSetting.__init__(self, setting.FontFamily, name,
-                               descr=descr, default=default)
+        _FieldSetting.__init__(
+            self, setting.FontFamily, name, descr=descr, default=default)
 
 class FieldFilename(_FieldSetting):
     """Select a filename with a browse button."""
 
     def __init__(self, name, descr=None, default=''):
-        _FieldSetting.__init__(self, setting.Filename, name,
-                               descr=descr, default=default)
-
+        _FieldSetting.__init__(
+            self, setting.Filename, name, descr=descr, default=default)
 
 class FieldColormap(_FieldSetting):
     """Return the name of a colormap."""
 
     def __init__(self, name, descr=None, default=''):
         _FieldSetting.__init__(
-            self, setting.Colormap, name,
-            descr=descr, default=default)
-
+            self, setting.Colormap, name, descr=descr, default=default)
