@@ -26,13 +26,11 @@ s.set(42)
 s.fromUIText('42')
 """
 
-from __future__ import division
 import re
 import sys
 
 import numpy as N
 
-from ..compat import cbasestr, cstr, crepr
 from .. import qtall as qt
 from . import controls
 from .settingdb import settingdb, uilocale, ui_floattostring, ui_stringtofloat
@@ -45,7 +43,7 @@ class OnModified(qt.QObject):
     """onmodified is emitted from an object contained in each setting."""
     onModified = qt.pyqtSignal()
 
-class Setting(object):
+class Setting:
     """A class to store a value with a particular type."""
 
     # differentiate widgets, settings and setting
@@ -197,7 +195,7 @@ class Setting(object):
         if (saveall or not self.isDefault()) and not self.readonly:
             if self._ref:
                 return "SetToReference('%s%s', %s)\n" % (
-                    rootname, self.name, crepr(self._ref.value))
+                    rootname, self.name, repr(self._ref.value))
             else:
                 return "Set('%s%s', %s)\n" % (
                     rootname, self.name, utils.rrepr(self.val))
@@ -353,7 +351,7 @@ class Str(Setting):
     typename = 'str'
 
     def normalize(self, val):
-        if isinstance(val, cbasestr):
+        if isinstance(val, str):
             return val
         raise utils.InvalidType
 
@@ -423,8 +421,9 @@ class Int(Setting):
 
         This needs to be overridden if the constructor changes
         """
-        return self._copyHelper((), (), {'minval': self.minval,
-                                         'maxval': self.maxval})
+        return self._copyHelper((), (), {
+            'minval': self.minval,
+            'maxval': self.maxval})
 
     def normalize(self, val):
         if isinstance(val, int):
@@ -482,8 +481,9 @@ class Float(Setting):
 
         This needs to be overridden if the constructor changes
         """
-        return self._copyHelper((), (), {'minval': self.minval,
-                                         'maxval': self.maxval})
+        return self._copyHelper((), (), {
+            'minval': self.minval,
+            'maxval': self.maxval})
 
     def normalize(self, val):
         if isinstance(val, int) or isinstance(val, float):
@@ -513,13 +513,13 @@ class FloatOrAuto(Float):
     def normalize(self, val):
         if type(val) in (int, float):
             return _finiteRangeFloat(val, minval=self.minval, maxval=self.maxval)
-        elif isinstance(val, cbasestr) and val.strip().lower() == 'auto':
+        elif isinstance(val, str) and val.strip().lower() == 'auto':
             return 'Auto'
         else:
             raise utils.InvalidType
 
     def toUIText(self):
-        if isinstance(self.val, cbasestr) and self.val.lower() == 'auto':
+        if isinstance(self.val, str) and self.val.lower() == 'auto':
             return 'Auto'
         else:
             return ui_floattostring(self.val)
@@ -565,13 +565,13 @@ class IntOrAuto(Setting):
     def normalize(self, val):
         if isinstance(val, int):
             return val
-        elif isinstance(val, cbasestr) and val.strip().lower() == 'auto':
+        elif isinstance(val, str) and val.strip().lower() == 'auto':
             return 'Auto'
         else:
             raise utils.InvalidType
 
     def toUIText(self):
-        if isinstance(self.val, cbasestr) and self.val.lower() == 'auto':
+        if isinstance(self.val, str) and self.val.lower() == 'auto':
             return 'Auto'
         else:
             return uilocale.toString(self.val)
@@ -669,7 +669,7 @@ class Distance(Setting):
         '%': _distPerc,
         '/': _distFrac,
         '': _distRatio
-        }
+    }
 
     # inverse functions for converting points to units
     inv_unit_func = {
@@ -688,7 +688,7 @@ class Distance(Setting):
         '%': _distInvPerc,
         '/': _distInvPerc,
         '': _distInvPerc
-        }
+    }
 
     @classmethod
     def isDist(kls, dist):
@@ -735,8 +735,8 @@ class Distance(Setting):
             return func(m, painter)
 
         # none of the regexps match
-        raise ValueError( "Cannot convert distance in form '%s'" %
-                          dist )
+        raise ValueError(
+            "Cannot convert distance in form '%s'" % dist )
 
     def convert(self, painter):
         """Convert this setting's distance as above"""
@@ -820,8 +820,12 @@ class Choice(Setting):
     def copy(self):
         """Make a copy of the setting."""
         return self._copyHelper(
-            (self.vallist,), (), {
-                'descriptions': self.descriptions, 'uilist': self.uilist})
+            (self.vallist,), (),
+            {
+                'descriptions': self.descriptions,
+                'uilist': self.uilist,
+            }
+        )
 
     def normalize(self, val):
         if val in self.vallist:
@@ -839,9 +843,11 @@ class Choice(Setting):
             raise utils.InvalidType
 
     def makeControl(self, *args):
-        return controls.Choice(self, False, self.vallist,
-                               descriptions=self.descriptions,
-                               uilist=self.uilist, *args)
+        return controls.Choice(
+            self, False, self.vallist,
+            descriptions=self.descriptions,
+            uilist=self.uilist, *args
+        )
 
 class ChoiceOrMore(Setting):
     """One out of a list of strings, or anything else."""
@@ -863,8 +869,11 @@ class ChoiceOrMore(Setting):
     def copy(self):
         """Make a copy of the setting."""
         return self._copyHelper(
-            (self.vallist,), (), {
-                'descriptions': self.descriptions})
+            (self.vallist,), (),
+            {
+                'descriptions': self.descriptions
+            }
+        )
 
     def normalize(self, val):
         return val
@@ -876,7 +885,7 @@ class ChoiceOrMore(Setting):
         return text
 
     def makeControl(self, *args):
-        argsv = {'descriptions': self.descriptions}
+        argsv = { 'descriptions': self.descriptions }
         return controls.Choice(self, True, self.vallist, *args, **argsv)
 
 class FloatChoice(ChoiceOrMore):
@@ -922,8 +931,10 @@ class FloatDict(Setting):
         return dict(val)
 
     def toUIText(self):
-        text = ['%s = %s' % (k, ui_floattostring(self.val[k]))
-                for k in sorted(self.val)]
+        text = [
+            '%s = %s' % (k, ui_floattostring(self.val[k]))
+            for k in sorted(self.val)
+        ]
         return '\n'.join(text)
 
     def fromUIText(self, text):
@@ -1006,7 +1017,7 @@ class WidgetPath(Str):
     typename = 'widget-path'
 
     def __init__(self, name, val, relativetoparent=True,
-                 allowedwidgets = None,
+                 allowedwidgets=None,
                  **args):
         """Initialise the setting.
 
@@ -1023,9 +1034,13 @@ class WidgetPath(Str):
 
     def copy(self):
         """Make a copy of the setting."""
-        return self._copyHelper((), (),
-                                {'relativetoparent': self.relativetoparent,
-                                 'allowedwidgets': self.allowedwidgets})
+        return self._copyHelper(
+            (), (),
+            {
+                'relativetoparent': self.relativetoparent,
+                'allowedwidgets': self.allowedwidgets,
+            }
+        )
 
     def getReferredWidget(self, val = None):
         """Get the widget referred to. We double-check here to make sure
@@ -1086,14 +1101,19 @@ class Dataset(Str):
 
     def copy(self):
         """Make a setting which has its values copied from this one."""
-        return self._copyHelper((), (),
-                                {'dimensions': self.dimensions,
-                                 'datatype': self.datatype})
+        return self._copyHelper(
+            (), (),
+            {
+                'dimensions': self.dimensions,
+                'datatype': self.datatype,
+            }
+        )
 
     def makeControl(self, *args):
         """Allow user to choose between the datasets."""
-        return controls.Dataset(self, self.getDocument(), self.dimensions,
-                                self.datatype, *args)
+        return controls.Dataset(
+            self, self.getDocument(), self.dimensions,
+            self.datatype, *args)
 
     def getData(self, doc):
         """Return a list of datasets entered."""
@@ -1101,7 +1121,7 @@ class Dataset(Str):
         if ( d is not None and
              d.datatype == self.datatype and
              (d.dimensions == self.dimensions or self.dimensions == 'all') ):
-                 return d
+            return d
 
 class Strings(Setting):
     """A multiple set of strings."""
@@ -1113,7 +1133,7 @@ class Strings(Setting):
         ('ds1','ds2'...)
         """
 
-        if isinstance(val, cbasestr):
+        if isinstance(val, str):
             return (val, )
 
         if type(val) not in (list, tuple):
@@ -1121,7 +1141,7 @@ class Strings(Setting):
 
         # check each entry in the list is appropriate
         for ds in val:
-            if not isinstance(ds, cbasestr):
+            if not isinstance(ds, str):
                 raise utils.InvalidType
 
         return tuple(val)
@@ -1150,7 +1170,7 @@ class Datasets(Setting):
         ('ds1','ds2'...)
         """
 
-        if isinstance(val, cbasestr):
+        if isinstance(val, str):
             return (val, )
 
         if type(val) not in (list, tuple):
@@ -1158,21 +1178,27 @@ class Datasets(Setting):
 
         # check each entry in the list is appropriate
         for ds in val:
-            if not isinstance(ds, cbasestr):
+            if not isinstance(ds, str):
                 raise utils.InvalidType
 
         return tuple(val)
 
     def copy(self):
         """Make a setting which has its values copied from this one."""
-        return self._copyHelper((), (),
-                                {'dimensions': self.dimensions,
-                                 'datatype': self.datatype})
+        return self._copyHelper(
+            (), (),
+            {
+                'dimensions': self.dimensions,
+                'datatype': self.datatype
+            }
+        )
 
     def makeControl(self, *args):
         """Allow user to choose between the datasets."""
-        return controls.Datasets(self, self.getDocument(), self.dimensions,
-                                 self.datatype, *args)
+        return controls.Datasets(
+            self, self.getDocument(), self.dimensions,
+            self.datatype, *args
+        )
 
     def getData(self, doc):
         """Return a list of datasets entered."""
@@ -1196,7 +1222,7 @@ class DatasetExtended(Dataset):
         floats (numbers).
         """
 
-        if isinstance(val, cbasestr):
+        if isinstance(val, str):
             return val
         elif self.dimensions == 1:
             # list of numbers only allowed for 1d datasets
@@ -1210,7 +1236,7 @@ class DatasetExtended(Dataset):
         raise utils.InvalidType
 
     def toUIText(self):
-        if isinstance(self.val, cbasestr):
+        if isinstance(self.val, str):
             return self.val
         else:
             # join based on , or ; depending on decimal point
@@ -1245,7 +1271,7 @@ class DatasetExtended(Dataset):
 
     def getFloatArray(self, doc):
         """Get a numpy of values or None."""
-        if isinstance(self.val, cbasestr):
+        if isinstance(self.val, str):
             ds = doc.evaluate.evalDatasetExpression(
                 self.val, datatype=self.datatype, dimensions=self.dimensions)
             if ds:
@@ -1258,7 +1284,7 @@ class DatasetExtended(Dataset):
 
     def isDataset(self, doc):
         """Is this setting a dataset?"""
-        return (isinstance(self.val, cbasestr) and
+        return (isinstance(self.val, str) and
                 doc.data.get(self.val))
 
     def isEmpty(self):
@@ -1267,7 +1293,7 @@ class DatasetExtended(Dataset):
 
     def getData(self, doc):
         """Return veusz dataset"""
-        if isinstance(self.val, cbasestr):
+        if isinstance(self.val, str):
             return doc.evaluate.evalDatasetExpression(
                 self.val, datatype=self.datatype, dimensions=self.dimensions)
         else:
@@ -1297,7 +1323,7 @@ class DatasetOrStr(Dataset):
         if checknull and not self.val:
             return None
         else:
-            return [cstr(self.val)]
+            return [str(self.val)]
 
     def makeControl(self, *args):
         return controls.DatasetOrString(self, self.getDocument(), *args)
@@ -1482,8 +1508,12 @@ class WidgetChoice(Str):
 
     def copy(self):
         """Make a copy of the setting."""
-        return self._copyHelper((), (),
-                                {'widgettypes': self.widgettypes})
+        return self._copyHelper(
+            (), (),
+            {
+                'widgettypes': self.widgettypes
+            }
+        )
 
     def buildWidgetList(self, level, widget, outdict):
         """A recursive helper to build up a list of possible widgets.
@@ -1596,7 +1626,7 @@ class LineSet(Setting):
             except ValueError:
                 raise utils.InvalidType
 
-            if ( not isinstance(color, cbasestr) or
+            if ( not isinstance(color, str) or
                  not Distance.isDist(width) or
                  style not in LineStyle._linestyles or
                  type(hide) not in (int, bool) ):
@@ -1663,7 +1693,7 @@ class FillSet(Setting):
             except ValueError:
                 raise utils.InvalidType
 
-            if ( not isinstance(color, cbasestr) or
+            if ( not isinstance(color, str) or
                  style not in utils.extfillstyles or
                  type(hide) not in (int, bool) or
                  len(fill) not in (3, 10) ):
@@ -1715,6 +1745,14 @@ class ImageFilename(Filename):
     def makeControl(self, *args):
         return controls.Filename(self, 'image', *args)
 
+class SVGFilename(Filename):
+    """Represents an svg filename setting."""
+
+    typename = 'filename-svg'
+
+    def makeControl(self, *args):
+        return controls.Filename(self, 'svg', *args)
+
 class FontFamily(Str):
     """Represents a font family."""
 
@@ -1724,6 +1762,28 @@ class FontFamily(Str):
         """Make a special font combobox."""
         return controls.FontFamily(self, *args)
 
+class FontStyle(Str):
+    """Represents a font style."""
+
+    typename = 'font-style'
+
+    def __init__(self, name, val, familysetnname, **args):
+        """Initialise font style.
+        familysetnname is a name of the family setting the style is associated
+        with."""
+
+        Str.__init__(self, name, val, **args)
+        self.familysetnname = familysetnname
+
+    def copy(self):
+        """Make a copy of the setting."""
+        return self._copyHelper( (), (self.familysetnname,), {})
+
+    def makeControl(self, *args):
+        familysetn = self.parent.get(self.familysetnname)
+
+        return controls.FontStyle(self, familysetn, *args)
+
 class ErrorStyle(Choice):
     """Error bar style.
     The allowed values are below in _errorstyles.
@@ -1738,8 +1798,11 @@ class ErrorStyle(Choice):
         'boxfill', 'diamondfill', 'curvefill',
         'fillvert', 'fillhorz',
         'linevert', 'linehorz',
-        'linevertbar', 'linehorzbar'
-        )
+        'linevertbar', 'linehorzbar',
+        'barhi', 'barlo',
+        'barendshi', 'barendslo',
+        'linehorzlo', 'linehorzhi', 'linevertlo', 'lineverthi',
+    )
 
     controls.ErrorStyle._errorstyles  = _errorstyles
 
@@ -1878,19 +1941,20 @@ class RotateInterval(Choice):
     '''Rotate a label with intervals given.'''
 
     def __init__(self, name, val, **args):
-        Choice.__init__(self, name,
-                        ('-180', '-135', '-90', '-45',
-                         '0', '45', '90', '135', '180'),
-                        val, **args)
+        Choice.__init__(
+            self, name,
+            ('-180', '-135', '-90', '-45', '0', '45', '90', '135', '180'),
+            val, **args
+        )
 
     def normalize(self, val):
         """Store rotate angle."""
         # backward compatibility with rotate option
         # False: angle 0
         # True:  angle 90
-        if val == False:
+        if val is False:
             val = '0'
-        elif val == True:
+        elif val is True:
             val = '90'
         return Choice.normalize(self, val)
 
@@ -1926,7 +1990,7 @@ class AxisBound(FloatOrAuto):
             mode = None
 
         v = self.val
-        if ( not isinstance(v, cbasestr) and v is not None and
+        if ( not isinstance(v, str) and v is not None and
              mode == 'datetime' ):
             return utils.dateFloatToString(v)
 
