@@ -330,6 +330,22 @@ _defaultmaps = {
         (38,  0,   128, 255),
     ),
 
+    # https://iamkate.com/data/12-bit-rainbow/
+    'rainbow-12bit': (
+        (0x77, 0x11, 0x88, 0xff),
+        (0x55, 0x33, 0xaa, 0xff),
+        (0x66, 0x66, 0xcc, 0xff),
+        (0x44, 0x99, 0xee, 0xff),
+        (0x00, 0xdd, 0xee, 0xff),
+        (0x55, 0xdd, 0x99, 0xff),
+        (0x88, 0xdd, 0x44, 0xff),
+        (0xbb, 0xcc, 0x22, 0xff),
+        (0xcc, 0xbb, 0x00, 0xff),
+        (0xcc, 0x99, 0x00, 0xff),
+        (0xbb, 0x66, 0x33, 0xff),
+        (0x99, 0x33, 0x66, 0xff),
+    ),
+
     'none': (
         (255, 255, 255, 255),
     ),
