@@ -16,15 +16,12 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import math
 import datetime
 import re
 
 import numpy as N
 
-from ..compat import crange, citems, cstr
-
 # date format: YYYY-MM-DDTHH:MM:SS.mmmmmm
 # date and time part are optional (check we have at least one!)
 date_re = re.compile( r'''
@@ -122,7 +119,7 @@ def dateFloatToString(f):
     if N.isfinite(f):
         return floatToDateTime(f).isoformat()
     else:
-        return cstr(f)
+        return str(f)
 
 def datetimeToTuple(dt):
     """Return tuple (year,month,day,hour,minute,second,microsecond) from
@@ -153,31 +150,33 @@ def addTimeTupleToDateTime(dt,  tt):
     """
 
     # add on most of the time intervals
-    dt = dt + datetime.timedelta(days=tt[2], hours=tt[3], 
-                                 minutes=tt[4], seconds=tt[5], 
-                                 microseconds=tt[6])
+    dt = dt + datetime.timedelta(
+        days=tt[2], hours=tt[3],
+        minutes=tt[4], seconds=tt[5],
+        microseconds=tt[6]
+    )
 
     # add on years
     dt = dt.replace(year=dt.year + tt[0])
-    
+
     # add on months - this could be much simpler
     if tt[1] > 0:
-        for i in crange(tt[1]):
+        for i in range(tt[1]):
             # find interval between this month and next...
             m, y = dt.month + 1, dt.year
             if m == 13:
                 m = 1
-                y += 1          
+                y += 1
             dt = dt.replace(year=y, month=m)
     elif tt[1] < 0:
-        for i in crange(abs(tt[1])):
+        for i in range(abs(tt[1])):
             # find interval between this month and next...
             m, y = dt.month - 1, dt.year
             if m == 0:
                 m = 12
-                y -= 1          
+                y -= 1
             dt = dt.replace(year=y, month=m)
-        
+
     return dt
 
 def roundDownToTimeTuple(dt,  tt):
@@ -195,10 +194,10 @@ def roundDownToTimeTuple(dt,  tt):
         i -= 1
     # round to nearest interval
     if (i == 1 or i == 2): # month, day
-        timein[i] == ((timein[i]-1) // tt[i])*tt[i] + 1
+        timein[i] = ((timein[i]-1) // tt[i])*tt[i] + 1
     else:
         timein[i] = (timein[i] // tt[i])*tt[i]
-        
+
     #print "rounded",  timein
     return tuple(timein)
 
@@ -213,19 +212,19 @@ def dateStrToRegularExpression(instr):
     # back again to the regular expression. This avoids the regular
     # expression being remapped.
     maps = (
-            ('YYYY', u'\ue001', r'(?P<YYYY>[0-9]{4})'),
-            ('YY',   u'\ue002', r'(?P<YY>[0-9]{2})'),
-            ('MM',   u'\ue003', r'(?P<MM>[0-9]{2})'),
-            ('M',    u'\ue004', r'(?P<MM>[0-9]{1,2})'),
-            ('DD',   u'\ue005', r'(?P<DD>[0-9]{2})'),
-            ('D',    u'\ue006', r'(?P<DD>[0-9]{1,2})'),
-            ('hh',   u'\ue007', r'(?P<hh>[0-9]{2})'),
-            ('h',    u'\ue008', r'(?P<hh>[0-9]{1,2})'),
-            ('mm',   u'\ue009', r'(?P<mm>[0-9]{2})'),
-            ('m',    u'\ue00a', r'(?P<mm>[0-9]{1,2})'),
-            ('ss',   u'\ue00b', r'(?P<ss>[0-9]{2}(\.[0-9]*)?)'),
-            ('s',    u'\ue00c', r'(?P<ss>[0-9]{1,2}(\.[0-9]*)?)'),
-        )
+        ('YYYY', '\ue001', r'(?P<YYYY>[0-9]{4})'),
+        ('YY',   '\ue002', r'(?P<YY>[0-9]{2})'),
+        ('MM',   '\ue003', r'(?P<MM>[0-9]{2})'),
+        ('M',    '\ue004', r'(?P<MM>[0-9]{1,2})'),
+        ('DD',   '\ue005', r'(?P<DD>[0-9]{2})'),
+        ('D',    '\ue006', r'(?P<DD>[0-9]{1,2})'),
+        ('hh',   '\ue007', r'(?P<hh>[0-9]{2})'),
+        ('h',    '\ue008', r'(?P<hh>[0-9]{1,2})'),
+        ('mm',   '\ue009', r'(?P<mm>[0-9]{2})'),
+        ('m',    '\ue00a', r'(?P<mm>[0-9]{1,2})'),
+        ('ss',   '\ue00b', r'(?P<ss>[0-9]{2}(\.[0-9]*)?)'),
+        ('s',    '\ue00c', r'(?P<ss>[0-9]{1,2}(\.[0-9]*)?)'),
+    )
 
     out = []
     for p in instr.split('|'):
@@ -243,7 +242,7 @@ def dateStrToRegularExpression(instr):
         out.append( '(?:%s)?' % p )
 
     # return final expression
-    return '^\s*%s\s*$' % (''.join(out))
+    return r'^\s*%s\s*$' % (''.join(out))
 
 def dateREMatchToDate(match):
     """Take match object for above regular expression,
@@ -254,7 +253,7 @@ def dateREMatchToDate(match):
 
     # remove None matches
     grps = {}
-    for k, v in citems(match.groupdict()):
+    for k, v in match.groupdict().items():
         if v is not None:
             grps[k] = v
 
