@@ -18,10 +18,8 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import math
 
-from ..compat import crange, citems
 from .. import qtall as qt
 from .. import document
 from .. import setting
@@ -37,7 +35,7 @@ def _(text, disambiguation=None, context='Key'):
 #############################################################################
 # classes for controlling key position interactively
 
-class ControlKey(object):
+class ControlKey:
     """Control the position of a key on a plot."""
 
     def __init__( self, widget, phelper, parentposn,
@@ -70,7 +68,8 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
         self.params = params
         self.setScaledRect(
             params.posn[0], params.posn[1],
-            params.dims[0], params.dims[1])
+            params.dims[0], params.dims[1]
+        )
 
         self.setCursor(qt.Qt.SizeAllCursor)
         self.setZValue(1.)
@@ -85,17 +84,17 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
             'left':   pposn[0] + th,
             'centre': pposn[0] + 0.5*(pposn[2]-pposn[0]-dims[0]),
             'right':  pposn[2] - th - dims[0]
-            }
+        }
         yposn = {
             'top':    pposn[1] + th,
             'centre': pposn[1] + 0.5*(pposn[3]-pposn[1]-dims[1]),
             'bottom': pposn[3] - th - dims[1]
-            }
+        }
 
         # these are special places where the key is aligned
         self.highlightpoints = {}
-        for xname, xval in citems(xposn):
-            for yname, yval in citems(yposn):
+        for xname, xval in xposn.items():
+            for yname, yval in yposn.items():
                 self.highlightpoints[(xname, yname)] = qt.QPointF(
                     xval*params.cgscale, yval*params.cgscale)
 
@@ -110,7 +109,7 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
 
         highlight = None
         highlightrect = qt.QRectF(rect.left()-10, rect.top()-10, 20, 20)
-        for name, point in citems(self.highlightpoints):
+        for name, point in self.highlightpoints.items():
             if highlightrect.contains(point):
                 highlight = name
                 break
@@ -153,7 +152,7 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
             document.OperationSettingSet(s.get('vertPosn'), vp),
             document.OperationSettingSet(s.get('horzManual'), hm),
             document.OperationSettingSet(s.get('vertManual'), vm),
-            )
+        )
         self.params.widget.document.applyOperation(
             document.OperationMultiple(operations, descr=_('move key')))
 
@@ -173,9 +172,9 @@ class Key(widget.Widget):
 
         s.add( setting.Text(
             'Text',
-            descr = _('Text settings'),
+            descr=_('Text settings'),
             usertext=_('Text')),
-               pixmap = 'settings_axislabel' )
+            pixmap='settings_axislabel' )
 
         s.add( setting.Str(
             'order', '',
@@ -194,71 +193,71 @@ class Key(widget.Widget):
 
         s.add( setting.KeyBrush(
             'Background',
-            descr = _('Key background fill'),
+            descr=_('Key background fill'),
             usertext=_('Background')),
-               pixmap = 'settings_bgfill' )
+            pixmap='settings_bgfill' )
         s.add( setting.Line(
             'Border',
-            descr = _('Key border line'),
+            descr=_('Key border line'),
             usertext=_('Border')),
-               pixmap = 'settings_border' )
+            pixmap='settings_border' )
 
         s.add( setting.AlignHorzWManual(
             'horzPosn',
             'right',
-            descr = _('Horizontal key position'),
+            descr=_('Horizontal key position'),
             usertext=_('Horz posn'),
             formatting=True) )
         s.add( setting.AlignVertWManual(
             'vertPosn',
             'bottom',
-            descr = _('Vertical key position'),
+            descr=_('Vertical key position'),
             usertext=_('Vert posn'),
             formatting=True) )
 
         s.add( setting.Distance(
             'keyLength',
             '1cm',
-            descr = _('Length of line to show in sample'),
+            descr=_('Length of line to show in sample'),
             usertext=_('Key length'),
             formatting=True) )
 
         s.add( setting.AlignVert(
             'keyAlign',
             'top',
-            descr = _('Alignment of key symbols relative to text'),
-            usertext = _('Key alignment'),
+            descr=_('Alignment of key symbols relative to text'),
+            usertext=_('Key alignment'),
             formatting=True) )
 
         s.add( setting.Float(
             'horzManual',
             0.,
-            descr = _('Manual horizontal fractional position'),
+            descr=_('Manual horizontal fractional position'),
             usertext=_('Horz manual'),
             formatting=True) )
         s.add( setting.Float(
             'vertManual',
             0.,
-            descr = _('Manual vertical fractional position'),
+            descr=_('Manual vertical fractional position'),
             usertext=_('Vert manual'),
             formatting=True) )
 
         s.add( setting.Float(
             'marginSize',
             1.,
-            minval = 0.,
-            descr = _('Width of margin in characters'),
+            minval=0.,
+            descr=_('Width of margin in characters'),
             usertext=_('Margin size'),
             formatting=True) )
 
         s.add( setting.Int(
             'columns',
             1,
-            descr = _('Number of columns in key'),
-            usertext = _('Columns'),
-            minval = 1,
-            maxval = 100,
-            formatting = True) )
+            descr=_('Number of columns in key'),
+            usertext=_('Columns'),
+            minval=1,
+            maxval=100,
+            formatting=True) )
 
         s.add( setting.Bool(
             'symbolswap',
@@ -267,6 +266,13 @@ class Key(widget.Widget):
             usertext=_('Swap symbol'),
             formatting=True) )
 
+        s.add( setting.Bool(
+            'orderswap',
+            False,
+            descr=_('Reverse order of entries'),
+            usertext=_('Reverse order'),
+            formatting=True) )
+
     @classmethod
     def allowedParentTypes(klass):
         from . import graph
@@ -315,7 +321,8 @@ class Key(widget.Widget):
         while not layout:
             # try to do a first cut of the layout, and expand the box until
             # everything fits
-            (layout, colstats, newrows) = self._layoutChunk(entries, (0, 0), (numrows, numcols))
+            (layout, colstats, newrows) = self._layoutChunk(
+                entries, (0, 0), (numrows, numcols))
             if not layout:
                 numrows = newrows
 
@@ -330,21 +337,23 @@ class Key(widget.Widget):
             victimcol = numcols
             while True:
                 # find the right-most column with excess occupation number
-                for i in reversed(crange(victimcol)):
+                for i in reversed(range(victimcol)):
                     if colstats[i] > meanoccupation:
                         victimcol = i
                         break
 
                 # find the last item in the victim column
                 victim = 0
-                for i in reversed(crange(len(layout))):
+                for i in reversed(range(len(layout))):
                     if layout[i][2] == victimcol:
                         victim = i
                         break
 
                 # try to relayout with the victim item shoved to the next column
-                (newlayout, newcolstats, newrows) = self._layoutChunk(entries[victim:],
-                                                        (0, victimcol+1), (numrows, numcols))
+                newlayout, newcolstats, newrows = self._layoutChunk(
+                    entries[victim:],
+                    (0, victimcol+1), (numrows, numcols)
+                )
                 if newlayout:
                     # the relayout worked, so accept it
                     layout = layout[0:victim] + newlayout
@@ -375,6 +384,8 @@ class Key(widget.Widget):
 
         s = self.settings
         font = s.get('Text').makeQFont(painter)
+        textpen = s.get('Text').makeQPen(painter)
+
         painter.setFont(font)
         height = utils.FontMetrics(font, painter.device()).height()
         margin = s.marginSize * height
@@ -388,7 +399,9 @@ class Key(widget.Widget):
         titlewidth, titleheight = 0, 0
         if s.title != '':
             titlefont = qt.QFont(font)
-            titlefont.setPointSize(max(font.pointSize() * 1.2, font.pointSize() + 2))
+            painter.setPen(textpen)
+            titlefont.setPointSizeF(
+                max(font.pointSize() * 1.2, font.pointSize() + 2))
             titlewidth, titleheight = utils.Renderer(
                 painter, titlefont,
                 0, 0, s.title,
@@ -407,6 +420,9 @@ class Key(widget.Widget):
             # default order
             widgets = [c for c in self.parent.children]
 
+        if s.orderswap:
+            widgets = widgets[::-1]
+
         # which widgets to exclude
         exclude = { x.strip() for x in s.exclude.split(',') }
 
@@ -420,7 +436,7 @@ class Key(widget.Widget):
                 continue
 
             # add an entry for each key entry for each widget
-            for i in crange(num):
+            for i in range(num):
                 lines = 1
                 if showtext:
                     w, h = utils.Renderer(
@@ -438,8 +454,10 @@ class Key(widget.Widget):
 
         # width of key part of key
         symbolwidth = s.get('keyLength').convert(painter)
-        keyswidth = ( (maxwidth + height + symbolwidth)*numcols +
-                      height*(numcols-1) )
+        keyswidth = (
+            (maxwidth + height + symbolwidth)*numcols +
+            height*(numcols-1)
+        )
         # total width of box
         totalwidth = max(keyswidth, titlewidth)
 
@@ -497,8 +515,6 @@ class Key(widget.Widget):
         # centres key below title
         x += (totalwidth-keyswidth)/2
 
-        textpen = s.get('Text').makeQPen(painter)
-
         swap = s.symbolswap
 
         # plot dataset entries
@@ -517,8 +533,9 @@ class Key(widget.Widget):
             sx = xpos
             if swap:
                 sx += maxwidth + height
-            plotter.drawKeySymbol(num, painter, sx, ypos+keyoffset,
-                                  symbolwidth, height)
+            plotter.drawKeySymbol(
+                num, painter, sx, ypos+keyoffset,
+                symbolwidth, height)
             painter.restore()
 
             # write key text
@@ -540,6 +557,7 @@ class Key(widget.Widget):
 
         phelper.setControlGraph(
             self,
-            [ControlKey(self, phelper, parentposn, boxposn, boxdims, height)] )
+            [ControlKey(self, phelper, parentposn, boxposn, boxdims, height)]
+        )
 
-document.thefactory.register( Key )
+document.thefactory.register(Key)
