@@ -19,30 +19,26 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import numpy as N
 
-from ..compat import CBool
-from .. import document
-
-class PickInfo(CBool):
-    """Encapsulates the results of a Pick operation. screenpos and coords are
+class PickInfo:
+    """Encapsulates the results of a Pick operation. graphpos and coords are
        numeric (x,y) tuples, labels are the textual labels for the x and y
        datasets, and index is some object that the picker can use to figure out
        what the 'next' and 'previous' points are. index must implement __str__();
        return '' if it has no user-visible meaning."""
-    def __init__(self, widget=None, screenpos=None, labels=None, coords=None, index=None):
+    def __init__(self, widget=None, graphpos=None, labels=None, coords=None, index=None):
         self.widget = widget
-        self.screenpos = screenpos
+        self.graphpos = graphpos
         self.labels = labels
         self.coords = coords
         self.index = index
         self.distance = float('inf')
         self.displaytype = ('numeric', 'numeric')
 
-    def cbool(self):
-        return bool(self.widget and self.screenpos and self.labels and
-                    self.coords)
+    def __bool__(self):
+        return bool(
+            self.widget and self.graphpos and self.labels and self.coords)
 
 class Index:
     """A class containing all the state a GenericPickable needs to find the
@@ -91,28 +87,41 @@ class GenericPickable:
     """Utility class which abstracts the math of picking the closest point out
        of a list of points"""
 
-    def __init__(self, widget, labels, vals, screenvals):
+    def __init__(self, widget, labels, vals, graphvals):
         self.widget = widget
         self.labels = labels
         self.xvals, self.yvals = vals
-        self.xscreen, self.yscreen = screenvals
+        self.xgraph, self.ygraph = graphvals
 
     def _pickSign(self, i):
-        if len(self.xscreen) <= 1:
+        if len(self.xgraph) <= 1:
             # we only have one element, so it doesn't matter anyways
             return 1
-        
-        if i == 0:
+
+        # go backwards to get previous finite point
+        mi = i-1
+        while mi >= 0 and not N.isfinite(self.xgraph[mi]+self.ygraph[mi]):
+            mi -= 1
+        if mi < 0:
             m = None
         else:
-            m = self.xscreen[i-1], self.yscreen[i-1]
+            m = self.xgraph[mi], self.ygraph[mi]
 
-        c = self.xscreen[i], self.yscreen[i]
+        # point in centre
+        c = self.xgraph[i], self.ygraph[i]
 
-        if i+1 == len(self.xscreen):
+        # find next finite point
+        pi = i+1
+        while pi < len(self.xgraph) and not N.isfinite(self.xgraph[pi]+self.ygraph[pi]):
+            pi += 1
+        if pi == len(self.xgraph):
             p = None
         else:
-            p = self.xscreen[i+1], self.yscreen[i+1]
+            p = self.xgraph[pi], self.ygraph[pi]
+
+        if p is None and m is None:
+            # only 1 point after removing non-finite points
+            return 1
 
         return _chooseOrderingSign(m, c, p)
 
@@ -124,29 +133,32 @@ class GenericPickable:
 
         if self.xvals is None or self.yvals is None:
             return info
-        if len(self.xscreen) == 0 or len(self.yscreen) == 0:
+        if len(self.xgraph) == 0 or len(self.ygraph) == 0:
             return info
 
         # calculate distances
         if distance_direction == 'vertical':
             # measure distance along y
-            dist = N.abs(self.yscreen - y0)
+            dist = N.abs(self.ygraph - y0)
         elif distance_direction == 'horizontal':
             # measure distance along x
-            dist = N.abs(self.xscreen - x0)
+            dist = N.abs(self.xgraph - x0)
         elif distance_direction == 'radial':
             # measure radial distance
-            dist = N.sqrt((self.xscreen - x0)**2 + (self.yscreen - y0)**2)
+            dist = N.sqrt((self.xgraph - x0)**2 + (self.ygraph - y0)**2)
         else:
             # programming error
             assert (distance_direction == 'radial' or
                     distance_direction == 'vertical' or
                     distance_direction == 'horizontal')
 
-        # ignore points which are offscreen
-        outofbounds = ( (self.xscreen < bounds[0]) | (self.xscreen > bounds[2]) |
-                        (self.yscreen < bounds[1]) | (self.yscreen > bounds[3]) )
-        dist[outofbounds] = float('inf')
+        # ignore points which are offgraph or not finite
+        with N.errstate(invalid='ignore'):
+            outofbounds = (
+                (self.xgraph < bounds[0]) | (self.xgraph > bounds[2]) |
+                (self.ygraph < bounds[1]) | (self.ygraph > bounds[3]) |
+                ~N.isfinite(self.xgraph) | ~N.isfinite(self.ygraph) )
+        dist[outofbounds] = N.inf
 
         m = N.min(dist)
         # if there are multiple equidistant points, arbitrarily take
@@ -157,7 +169,7 @@ class GenericPickable:
         except IndexError:
             return info
 
-        info.screenpos = self.xscreen[i], self.yscreen[i]
+        info.graphpos = self.xgraph[i], self.ygraph[i]
         info.coords = self.xvals[i], self.yvals[i]
         info.distance = m
         info.index = Index(self.xvals[i], i, self._pickSign(i))
@@ -196,16 +208,18 @@ class GenericPickable:
 
         i += incr
 
-        # skip points that are outside of the bounds
-        while ( i >= 0 and i < len(self.xscreen) and
-            (self.xscreen[i] < bounds[0] or self.xscreen[i] > bounds[2] or
-             self.yscreen[i] < bounds[1] or self.yscreen[i] > bounds[3]) ):
+        # skip points that are outside of the bounds or are not finite
+        while (i >= 0 and i < len(self.xgraph) and
+                ( not N.isfinite(self.xgraph[i]) or
+                  not N.isfinite(self.ygraph[i]) or
+                  (self.xgraph[i] < bounds[0] or self.xgraph[i] > bounds[2] or
+                   self.ygraph[i] < bounds[1] or self.ygraph[i] > bounds[3]) )):
             i += incr
 
-        if i < 0 or i >= len(self.xscreen):
+        if i < 0 or i >= len(self.xgraph):
             return info
 
-        info.screenpos = self.xscreen[i], self.yscreen[i]
+        info.graphpos = self.xgraph[i], self.ygraph[i]
         info.coords = self.xvals[i], self.yvals[i]
         info.index = Index(self.xvals[i], i, oldindex.sign)
 
@@ -225,15 +239,10 @@ class DiscretePickable(GenericPickable):
             GenericPickable.__init__( self, widget, labels, (None, None), (None, None) )
             return
 
-        # map all the valid data
-        x, y = N.array([]), N.array([])
-        xs, ys = N.array([]), N.array([])
-        for xvals, yvals in document.generateValidDatasetParts(xdata, ydata):
-            chunklen = min(len(xvals.data), len(yvals.data))
-
-            x = N.append(x, xvals.data[:chunklen])
-            y = N.append(y, yvals.data[:chunklen])
-
+        # take data, ensure same size and map it
+        x, y = xdata.data, ydata.data
+        minlen = min(len(x), len(y))
+        x, y = x[:minlen], y[:minlen]
         xs, ys = mapdata_fn(x, y)
 
         # and set us up with the mapped data
@@ -241,10 +250,10 @@ class DiscretePickable(GenericPickable):
 
     def pickPoint(self, x0, y0, bounds, distance_direction):
         info = GenericPickable.pickPoint(self, x0, y0, bounds, distance_direction)
-        info.displaytype = (self.xdata.displaytype, self.ydata.displaytype)
-
         if not info:
-            return info
+            return None
+
+        info.displaytype = (self.xdata.displaytype, self.ydata.displaytype)
 
         # indicies are persistent
         info.index.useindex = True
