@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2011 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -17,10 +16,8 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import os.path
 
-import sip
 from .. import qtall as qt
 from .. import utils
 from .. import setting
@@ -173,8 +170,8 @@ Enter key.</p>
 '''), mainwin,
             flash = mainwin.propdock,
             disablenext = True,
-            nextonsetting = ('/page1/graph1/x/label',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/x/label', lambda val: val != ''),
             nextstep = StepPropertiesWin2)
 
 class StepPropertiesWin2(TutorialStep):
@@ -241,8 +238,9 @@ be <code>x**2</code>, plotting x squared.</p>
 <p>(Veusz uses Python syntax for its functions, so the power operator
 is <code>**</code>, rather than <code>^</code>)</p>
 '''), mainwin,
-            nextonsetting = ('/page1/graph1/function1/function',
-                             lambda val: val.strip() == 'x**2'),
+            nextonsetting = (
+                '/page1/graph1/function1/function',
+                lambda val: val.strip() == 'x**2'),
             disablenext = True,
             nextstep=FunctionFormatting)
 
@@ -298,8 +296,9 @@ function line.</p>
 '''),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/function1/Line/color',
-                             lambda val: val.strip() != 'black'),
+            nextonsetting = (
+                '/page1/graph1/function1/Line/color',
+                lambda val: val.strip() != 'black'),
             nextstep=DataStart)
 
 ###########
@@ -339,8 +338,9 @@ class DataImport(TutorialStep):
             nextstep=DataImportDialog)
 
         # make sure we have the default delimiters
-        for k in ( 'importdialog_csvdelimitercombo_HistoryCombo',
-                   'importdialog_csvtextdelimitercombo_HistoryCombo' ):
+        for k in (
+                'importdialog_csvdelimitercombo_HistoryCombo',
+                'importdialog_csvtextdelimitercombo_HistoryCombo' ):
             if k in setting.settingdb:
                 del setting.settingdb[k]
 
@@ -453,8 +453,9 @@ widget. Click on this, or go to the Insert menu and choose "Add xy".</p>
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/xData',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/xy1/xData',
+                lambda val: val != ''),
             nextstep=SetXY_X)
 
 class SetXY_X(TutorialStep):
@@ -468,8 +469,9 @@ class SetXY_X(TutorialStep):
 menu or type it.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/xData',
-                             lambda val: val == 'alpha'),
+            nextonsetting = (
+                '/page1/graph1/xy1/xData',
+                lambda val: val == 'alpha'),
             nextstep=SetXY_Y)
 
 class SetXY_Y(TutorialStep):
@@ -480,8 +482,9 @@ class SetXY_Y(TutorialStep):
 <code>beta</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/yData',
-                             lambda val: val == 'beta'),
+            nextonsetting = (
+                '/page1/graph1/xy1/yData',
+                lambda val: val == 'beta'),
             nextstep=SetXYLine)
 
 class SetXYLine(TutorialStep):
@@ -499,8 +502,9 @@ the bottom, to hide the line plotted between the data points.</p>
 ''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotline.svg')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/PlotLine/hide',
-                             lambda val: val),
+            nextonsetting = (
+                '/page1/graph1/xy1/PlotLine/hide',
+                lambda val: val),
             nextstep=SetXYFill)
 
 class SetXYFill(TutorialStep):
@@ -514,8 +518,9 @@ Change the fill color of the plotted data.</p>
 ''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotmarkerfill.svg')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/MarkerFill/color',
-                             lambda val: val != 'black'),
+            nextonsetting = (
+                '/page1/graph1/xy1/MarkerFill/color',
+                lambda val: val != 'black'),
             nextstep=AddXY2nd)
 
 class AddXY2nd(TutorialStep):
@@ -533,8 +538,9 @@ flashing icon, or go to the Insert menu and choose "Add xy".</p>
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/xData',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/xy2/xData',
+                lambda val: val != ''),
             nextstep=AddXY2nd_2)
 
 class AddXY2nd_2(TutorialStep):
@@ -545,8 +551,9 @@ class AddXY2nd_2(TutorialStep):
 <code>alpha</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/xData',
-                             lambda val: val == 'alpha'),
+            nextonsetting = (
+                '/page1/graph1/xy2/xData',
+                lambda val: val == 'alpha'),
             nextstep=AddXY2nd_3)
 
 class AddXY2nd_3(TutorialStep):
@@ -557,8 +564,9 @@ class AddXY2nd_3(TutorialStep):
 <code>gamma</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/yData',
-                             lambda val: val == 'gamma'),
+            nextonsetting = (
+                '/page1/graph1/xy2/yData',
+                lambda val: val == 'gamma'),
             nextstep=AddXY2nd_4)
 
 class AddXY2nd_4(TutorialStep):
@@ -573,8 +581,9 @@ option.</p>
 ''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotfillbelow.png')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/FillBelow/hide',
-                             lambda val: not val),
+            nextonsetting = (
+                '/page1/graph1/xy2/FillBelow/hide',
+                lambda val: not val),
             nextstep=File1)
 
 class File1(TutorialStep):
@@ -666,8 +675,9 @@ class AddGrid(TutorialStep):
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.grid']),
             disablenext=True,
-            nextonsetting = ('/page1/grid1/rows',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/rows',
+                lambda val: val != ''),
             nextstep=Paste1)
 
 class Paste1(TutorialStep):
@@ -682,8 +692,9 @@ from the Edit menu.</p>
             disablenext=True,
             flash=mainwin.treeedit.edittoolbar.widgetForAction(
                 mainwin.vzactions['edit.paste']),
-            nextonsetting = ('/page1/grid1/graph1/leftMargin',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/graph1/leftMargin',
+                lambda val: val != ''),
             nextstep=Paste2)
 
 class Paste2(TutorialStep):
@@ -698,8 +709,9 @@ or choose "Paste" from the Edit menu.</p>
             disablenext=True,
             flash=mainwin.treeedit.edittoolbar.widgetForAction(
                 mainwin.vzactions['edit.paste']),
-            nextonsetting = ('/page1/grid1/graph2/leftMargin',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/graph2/leftMargin',
+                lambda val: val != ''),
             nextstep=Paste3)
 
 class Paste3(TutorialStep):
@@ -713,8 +725,9 @@ change the graphs to be arranged in rows.</p>
 number of columns to 1.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/grid1/columns',
-                             lambda val: val == 1),
+            nextonsetting = (
+                '/page1/grid1/columns',
+                lambda val: val == 1),
             nextstep=Paste4)
 
 class Paste4(TutorialStep):
@@ -754,7 +767,7 @@ class TutorialDock(qt.QDockWidget):
         self.setWindowTitle('Tutorial - Veusz')
         self.setObjectName('veusztutorialwindow')
 
-        self.setStyleSheet('background: lightyellow;')
+        self.setStyleSheet('background: lightyellow; color: black;')
 
         self.document = document
         self.mainwin = mainwin
@@ -764,9 +777,9 @@ class TutorialDock(qt.QDockWidget):
         txtdoc = qt.QTextDocument(self)
         txtdoc.setDefaultStyleSheet(
             "p.usercmd { color: blue; } "
-            "h1 { font-size: x-large;} "
+            "h1 { font-size: x-large; color: darkblue; } "
             "code { color: green;} "
-            )
+        )
         self.textedit = qt.QTextEdit(readOnly=True)
         self.textedit.setDocument(txtdoc)
 
@@ -839,12 +852,12 @@ class TutorialDock(qt.QDockWidget):
         # it: hence the sip.isdeleted
 
         if ( self.flash is not self.oldflash and self.oldflash is not None
-             and not sip.isdeleted(self.oldflash) ):
+             and not qt.sip.isdeleted(self.oldflash) ):
             # clear any flashing on previous widget
             self.oldflash.setStyleSheet('')
             self.oldflash = None
 
-        if self.flash is not None and not sip.isdeleted(self.flash):
+        if self.flash is not None and not qt.sip.isdeleted(self.flash):
             # set flash state and toggle variable
             if self.flashon:
                 self.flash.setStyleSheet('background: yellow;')
