@@ -18,16 +18,13 @@
 
 """Routines to export the document."""
 
-from __future__ import division
 import os.path
 import random
-import math
 import codecs
 import re
 import sys
 import subprocess
 
-from ..compat import crange
 from .. import qtall as qt
 from .. import setting
 from .. import utils
@@ -104,17 +101,17 @@ class ExportBitmapRunnable(ExportRunnable):
         if fmt == 'png':
             # transparent output
             image = qt.QImage(
-                size[0], size[1],
+                int(size[0]), int(size[1]),
                 qt.QImage.Format_ARGB32_Premultiplied)
         else:
             # non transparent output
             image = qt.QImage(
-                size[0], size[1],
+                int(size[0]), int(size[1]),
                 qt.QImage.Format_RGB32)
             backqcolor.setAlpha(255)
 
-        image.setDotsPerMeterX(self.phelpers[0].dpi[0]*m_inch)
-        image.setDotsPerMeterY(self.phelpers[0].dpi[1]*m_inch)
+        image.setDotsPerMeterX(int(self.phelpers[0].dpi[0]*m_inch))
+        image.setDotsPerMeterY(int(self.phelpers[0].dpi[1]*m_inch))
         if backqcolor.alpha() == 0:
             image.fill(qt.qRgba(0,0,0,0))
         else:
@@ -477,7 +474,7 @@ class AsyncExport(qt.QObject):
             '.selftest': ExportSelfTestRunnable,
             '.pic': ExportPICRunnable,
             '.emf': ExportEMFRunnable,
-            }[ext](self, filename, phelpers)
+        }[ext](self, filename, phelpers)
 
         self.pool.start(runnable)
 
@@ -560,9 +557,9 @@ def printDialog(parentwindow, document, filename=None):
 
         # reverse or forward order
         if prnt.pageOrder() == qt.QPrinter.FirstPageFirst:
-            pages = list(crange(minval, maxval+1))
+            pages = list(range(minval, maxval+1))
         else:
-            pages = list(crange(maxval, minval-1, -1))
+            pages = list(range(maxval, minval-1, -1))
 
         # if more copies are requested
         pages *= prnt.copyCount()
