@@ -18,7 +18,6 @@
 
 """A database for default values of settings."""
 
-from __future__ import division, print_function
 import sys
 import datetime
 
@@ -80,12 +79,16 @@ defaultValues = {
     'export_template_single': '%DOCNAME%',
     'export_template_multi': '%DOCNAME%_%PAGE00%',
 
+    # add import paths
+    'docfile_addimportpaths': True,
+
     # ask tutorial before?
     'ask_tutorial': False,
 
     # log picked points to clipboard or to console
     'picker_to_clipboard': False,
     'picker_to_console': True,
+    'picker_sig_figs': 5,
 
     # add these directories to the python path (colon-separated)
     'external_pythonpath': '',
@@ -108,9 +111,13 @@ defaultValues = {
     # (packagers, please don't disable here but in veusz/setting/feedback.py)
     'feedback_disabled': False,
     'feedback_asked_user': False,
-    }
 
-class _SettingDB(object):
+    # locations considered secure to load
+    'secure_dirs': [],
+    'secure_unsaved': True,
+}
+
+class _SettingDB:
     """A class which provides access to a persistant settings database.
 
     Items are accesses as a dict, with items as key=value
@@ -125,7 +132,7 @@ class _SettingDB(object):
         'command': 'blue',
         'cntrlline': 'blue',
         'cntrlcorner': 'black',
-        }
+    }
 
     def __init__(self):
         """Initialise the object, reading the settings."""
@@ -175,8 +182,9 @@ class _SettingDB(object):
             try:
                 self.database[realkey] = eval(val)
             except:
-                print('Error interpreting item "%s" in '
-                      'settings file' % realkey, file=sys.stderr)
+                print(
+                    'Error interpreting item "%s" in '
+                    'settings file' % realkey, file=sys.stderr)
 
         # set any defaults which haven't been set
         for key in defaultValues:
