@@ -18,11 +18,9 @@
 
 '''Non orthogonal function plotting.'''
 
-from __future__ import division
 import numpy as N
 
-from ..compat import cstr
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
 from .. import setting
 from .. import utils
@@ -33,7 +31,7 @@ from .widget import Widget
 
 def _(text, disambiguation=None, context='NonOrthFunction'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class NonOrthFunction(Widget):
     '''Widget for plotting a function on a non-orthogonal plot.'''
@@ -47,39 +45,45 @@ class NonOrthFunction(Widget):
         '''Settings for widget.'''
         Widget.addSettings(s)
 
-        s.add( setting.Str('function', 'a',
-                           descr=_('Function expression'),
-                           usertext=_('Function')) )
-        s.add( setting.Choice('variable', ['a', 'b'], 'a',
-                              descr=_('Variable the function is a function of'),
-                              usertext=_('Variable')) )
-        s.add(setting.FloatOrAuto('min', 'Auto',
-                                  descr=_('Minimum value at which to plot function'),
-                                  usertext=_('Min')))
-        
-        s.add(setting.FloatOrAuto('max', 'Auto',
-                                  descr=_('Maximum value at which to plot function'),
-                                  usertext=_('Max')))
+        s.add( setting.Str(
+            'function', 'a',
+            descr=_('Function expression'),
+            usertext=_('Function')) )
+        s.add( setting.Choice(
+            'variable', ['a', 'b'], 'a',
+            descr=_('Variable the function is a function of'),
+            usertext=_('Variable')) )
+        s.add(setting.FloatOrAuto(
+            'min', 'Auto',
+            descr=_('Minimum value at which to plot function'),
+            usertext=_('Min')))
 
+        s.add(setting.FloatOrAuto(
+            'max', 'Auto',
+            descr=_('Maximum value at which to plot function'),
+            usertext=_('Max')))
 
-        s.add( setting.Line('PlotLine',
-                            descr = _('Plot line settings'),
-                            usertext = _('Plot line')),
-               pixmap = 'settings_plotline' )
+        s.add( setting.Line(
+            'PlotLine',
+            descr=_('Plot line settings'),
+            usertext=_('Plot line')),
+            pixmap='settings_plotline' )
         s.get('PlotLine').get('color').newDefault('auto')
-        s.add( FillBrush('Fill1',
-                         descr = _('Fill settings (1)'),
-                         usertext = _('Area fill 1')),
-               pixmap = 'settings_plotfillbelow' )
-        s.add( FillBrush('Fill2',
-                         descr = _('Fill settings (2)'),
-                         usertext = _('Area fill 2')),
-               pixmap = 'settings_plotfillbelow' )
+        s.add( FillBrush(
+            'Fill1',
+            descr=_('Fill settings (1)'),
+            usertext=_('Area fill 1')),
+            pixmap='settings_plotfillbelow' )
+        s.add( FillBrush(
+            'Fill2',
+            descr=_('Fill settings (2)'),
+            usertext=_('Area fill 2')),
+            pixmap='settings_plotfillbelow' )
 
-        s.add( setting.Int('steps', 50,
-                           descr = _('Number of steps to evaluate the function'
-                                     ' over'),
-                           usertext=_('Steps'), formatting=True), 0 )
+        s.add( setting.Int(
+            'steps', 50,
+            descr = _('Number of steps to evaluate the function over'),
+            usertext=_('Steps'), formatting=True), 0 )
 
     @classmethod
     def allowedParentTypes(klass):
@@ -97,7 +101,7 @@ class NonOrthFunction(Widget):
         '''Write error message to document log for exception ex.'''
         self.document.log(
             "Error evaluating expression in function widget '%s': '%s'" % (
-                self.name, cstr(ex)))
+                self.name, str(ex)))
 
     def getFunctionPoints(self):
         '''Get points for plotting function.
@@ -113,8 +117,8 @@ class NonOrthFunction(Widget):
 
         steps = max(2, s.steps)
         # input values for function
-        invals = ( N.arange(steps)*(1./(steps-1))*(crange[1]-crange[0]) +
-                   crange[0] )
+        invals = (
+            N.arange(steps)*(1./(steps-1))*(crange[1]-crange[0]) + crange[0] )
 
         # do evaluation
         env = self.initEnviron()
@@ -173,13 +177,13 @@ class NonOrthFunction(Widget):
         px, py = self.parent.graphToPlotCoords(apts, bpts)
 
         x1, y1, x2, y2 = posn
-        cliprect = qt4.QRectF( qt4.QPointF(x1, y1), qt4.QPointF(x2, y2) )
+        cliprect = qt.QRectF( qt.QPointF(x1, y1), qt.QPointF(x2, y2) )
         painter = phelper.painter(self, posn)
         with painter:
             self.parent.setClip(painter, posn)
 
             # plot line
-            painter.setBrush(qt4.QBrush())
+            painter.setBrush(qt.QBrush())
             painter.setPen( s.PlotLine.makeQPenWHide(painter) )
             for x, y in utils.validLinePoints(px, py):
                 if not s.Fill1.hide:
@@ -187,10 +191,10 @@ class NonOrthFunction(Widget):
                 if not s.Fill2.hide:
                     self.parent.drawFillPts(painter, s.Fill2, cliprect, x, y)
                 if not s.PlotLine.hide:
-                    p = qt4.QPolygonF()
+                    p = qt.QPolygonF()
                     utils.addNumpyToPolygonF(p, x, y)
-                    painter.setBrush(qt4.QBrush())
+                    painter.setBrush(qt.QBrush())
                     painter.setPen( s.PlotLine.makeQPen(painter) )
                     utils.plotClippedPolyline(painter, cliprect, p)
 
-document.thefactory.register( NonOrthFunction )
+document.thefactory.register(NonOrthFunction)
