@@ -21,8 +21,7 @@
 
 """A generic plotter widget which is inherited by function and point."""
 
-from __future__ import division
-from .. import qtall as qt4
+from .. import qtall as qt
 import numpy as N
 
 from .. import setting
@@ -31,7 +30,7 @@ from . import widget
 
 def _(text, disambiguation=None, context='Plotters'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class GenericPlotter(widget.Widget):
     """Generic plotter."""
@@ -39,10 +38,6 @@ class GenericPlotter(widget.Widget):
     typename='genericplotter'
     isplotter = True
 
-    def __init__(self, parent, name=None):
-        """Initialise object, setting axes."""
-        widget.Widget.__init__(self, parent, name=name)
-
     @classmethod
     def allowedParentTypes(klass):
         from . import graph
@@ -53,15 +48,23 @@ class GenericPlotter(widget.Widget):
         """Construct list of settings."""
         widget.Widget.addSettings(s)
 
-        s.add( setting.Str('key', '',
-                           descr = _('Description of the plotted data to appear in key'),
-                           usertext=_('Key text')) )
-        s.add( setting.Axis('xAxis', 'x', 'horizontal',
-                            descr = _('Name of X-axis to use'),
-                            usertext=_('X axis')) )
-        s.add( setting.Axis('yAxis', 'y', 'vertical',
-                            descr = _('Name of Y-axis to use'),
-                            usertext=_('Y axis')) )
+        s.add( setting.Str(
+            'key', '',
+            descr=_('Description of the plotted data to appear in key'),
+            usertext=_('Key text')) )
+        s.add( setting.Axis(
+            'xAxis', 'x', 'horizontal',
+            descr=_('Name of X-axis to use'),
+            usertext=_('X axis')) )
+        s.add( setting.Axis(
+            'yAxis', 'y', 'vertical',
+            descr=_('Name of Y-axis to use'),
+            usertext=_('Y axis')) )
+
+    def autoColor(self, painter, dataindex=0):
+        """Automatic color for plotting."""
+        return painter.docColorAuto(
+            painter.helper.autoColorIndex((self, dataindex)))
 
     def getAxesNames(self):
         """Returns names of axes used."""
@@ -98,7 +101,7 @@ class GenericPlotter(widget.Widget):
             y1, y2 = y2, y1
 
         # actually clip the data
-        cliprect = qt4.QRectF(qt4.QPointF(x1, y1), qt4.QPointF(x2, y2))
+        cliprect = qt.QRectF(qt.QPointF(x1, y1), qt.QPointF(x2, y2))
         return cliprect
 
     def getAxisLabels(self, direction):
@@ -170,6 +173,10 @@ class GenericPlotter(widget.Widget):
         painter = painthelper.painter(self, posn, clip=cliprect)
         with painter:
             self.dataDraw(painter, axes, posn, cliprect)
+
+        for c in self.children:
+            c.draw(posn, painthelper, outerbounds)
+
         return posn
 
     def dataDraw(self, painter, axes, posn, cliprect):
@@ -194,27 +201,29 @@ class FreePlotter(widget.Widget):
         widget.Widget.addSettings(s)
 
         s.add( setting.DatasetExtended(
-                'xPos', [0.5],
-                descr=_('List of fractional X coordinates or dataset'),
-                usertext=_('X positions'),
-                formatting=False) )
+            'xPos', [0.5],
+            descr=_('List of fractional X coordinates or dataset'),
+            usertext=_('X positions'),
+            formatting=False) )
         s.add( setting.DatasetExtended(
-                'yPos', [0.5],
-                descr=_('List of fractional Y coordinates or dataset'),
-                usertext=_('Y positions'),
-                formatting=False) )
-        s.add( setting.Choice('positioning',
-                              ['axes', 'relative'], 'relative',
-                              descr=_('Use axes or fractional '
-                                      'position to place label'),
-                              usertext=_('Position mode'),
-                              formatting=False) )
-        s.add( setting.Axis('xAxis', 'x', 'horizontal',
-                            descr = _('Name of X-axis to use'),
-                            usertext=_('X axis')) )
-        s.add( setting.Axis('yAxis', 'y', 'vertical',
-                            descr = _('Name of Y-axis to use'),
-                            usertext=_('Y axis')) )
+            'yPos', [0.5],
+            descr=_('List of fractional Y coordinates or dataset'),
+            usertext=_('Y positions'),
+            formatting=False) )
+        s.add( setting.Choice(
+            'positioning',
+            ['axes', 'relative'], 'relative',
+            descr=_('Use axes or fractional position to place label'),
+            usertext=_('Position mode'),
+            formatting=False) )
+        s.add( setting.Axis(
+            'xAxis', 'x', 'horizontal',
+            descr=_('Name of X-axis to use'),
+            usertext=_('X axis')) )
+        s.add( setting.Axis(
+            'yAxis', 'y', 'vertical',
+            descr=_('Name of Y-axis to use'),
+            usertext=_('Y axis')) )
 
     def _getPlotterCoords(self, posn, xsetting='xPos', ysetting='yPos'):
         """Calculate coordinates from relative or axis positioning.
@@ -230,8 +239,7 @@ class FreePlotter(widget.Widget):
         if s.positioning == 'axes':
 
             if hasattr(self.parent, 'getAxes'):
-                axes = self.parent.getAxes( (s.xAxis,
-                                             s.yAxis) )
+                axes = self.parent.getAxes( (s.xAxis, s.yAxis) )
             else:
                 return None, None
             if axes[0] is None or axes[1] is None:
@@ -257,7 +265,7 @@ class FreePlotter(widget.Widget):
                 return None, None
             if axes[0] is None or axes[1] is None:
                 return None, None
-            
+
             xpos = axes[0].plotterToDataCoords(posn, xplt)
             ypos = axes[1].plotterToDataCoords(posn, yplt)
         else:
